
#This is the corresponding code for all analyses in: 
#Ebel, J.D., S.J. Leroux, M.J. Robertson, J.B. Dempson. [submitted]. Ontogenetic differences in Atlantic salmon whole body phosphorus concentration and its implications for cross-ecosystem fluxes.

#The code is broken into sections, but the sections are cumulative, meaning that the code must be run in the order provided.

#Clear the console of all previous objects. 
rm(list=ls(all=TRUE))
#To clear commands from console on a PC use Ctrl-L

#Required datafiles: THIS CODE WILL NOT RUN UNLESS YOU IMPORT THE DATAFILES 
#atlantic.salmon.body.composition.csv
#adult.weights.csv
#adult.lw.csv
#kelt.lw.csv
#salmon.count.csv

#THIS CODE WILL NOT RUN UNLESS YOU IMPORT THE DATAFILES with the names given below.
atlantic.salmon.body.composition<-read.csv("atlantic.salmon.body.composition.csv")
adult.weights <- read.csv("adult.weights.csv")
kelt.lw <- read.csv("kelt.lw.csv")
adult.lw<-read.csv("adult.lw.csv")
salmon <- read.csv("salmon.count.csv")


################################################################################################################################
#Atlantic salmon elemental composition.

data<- atlantic.salmon.body.composition

#figshare datafile name: atlantic.salmon.body.composition.csv

#p=phosphorus, ca=calcium, mg=magnesium, k=potassium, na=sodium, s=sulfur, fe=iron. 
#In the new dataframe capital letters indicate raw value on wet weight basis (i.e., micrograms/gram), #
#lowercase denotes percent of wet mass
data$p<-  (data$P/1000000)*100
data$ca<- (data$Ca/1000000)*100
data$mg<- (data$Mg/1000000)*100
data$k<-  (data$K/1000000)*100
data$na<- (data$Na/1000000)*100
data$s<-  (data$S/1000000)*100
data$fe<- (data$Fe/1000000)*100

raw<-data
rm(data)

data<-data.frame(cbind(id=raw$fish.id, river=raw$river, life.stage=raw$life.stage, fk.lgt=raw$fk.lgt, cut.wt=raw$cut.wt, dry.wt=raw$dry.wt,p=raw$p, ca=raw$ca, mg=raw$mg, k=raw$k, na=raw$na, s=raw$s))

#Calculate %NUTRIENT on a dry weight basis. Also calculates the other elements included in the macropanel analysis except for Fe. There is no special reason why Fe is omitted below. It just is. 
#All analyses outside of this section rely only on P and Ca. 
data$p.d<-(((1/(raw$dry.wt/100))*raw$P)/1000000)*100
data$ca.d<-(((1/(raw$dry.wt/100))*raw$Ca)/1000000)*100
data$mg.d<-(((1/(raw$dry.wt/100))*raw$Mg)/1000000)*100
data$na.d<-(((1/(raw$dry.wt/100))*raw$Na)/1000000)*100
data$s.d<-(((1/(raw$dry.wt/100))*raw$S)/1000000)*100
data$k.d<-(((1/(raw$dry.wt/100))*raw$K)/1000000)*100

#Nutrient concentration by dry wt.
data$P.d<-((raw$dry.wt/100)*raw$P)/1000000
data$Ca.d<-((raw$dry.wt/100)*raw$Ca)/1000000

#Molar mass
data$P.m<-(data$P.d/30.9737)
data$Ca.m<-(data$Ca.d/40.078)

#Ca:P ratio
data$ratio<-data$Ca.m/data$P.m

macropanel<-data
rm(data)

#Model Selection for testing for differences among populations and life stages.
#I need to construct linear models -> population, life stage, and population X life stage, 
#then compare the fit of the data to those models using AIC.
data<-macropanel
p.content<-data.frame(cbind(river=data$river, life.stage=data$life.stage, p=data$p))

GLM_1<-glm(p~river, family=gaussian, data=p.content)
summary(GLM_1)

GLM_2<-glm(p~life.stage, family=gaussian, data=p.content)
summary(GLM_2)

GLM_3<-glm(p~life.stage + river, family=gaussian, data=p.content)
summary(GLM_3)

GLM_4<-glm(p~1, family=gaussian, data=p.content)
summary (GLM_4)

Cand.models<-list()
Cand.models[[1]]<-glm(p~river, family=gaussian, data=p.content)
Cand.models[[2]]<-glm(p~life.stage, family=gaussian, data=p.content)
Cand.models[[3]]<-glm(p~river + life.stage, family=gaussian, data=p.content)
Cand.models[[4]]<-glm(p~1, family=gaussian, data=p.content)

Modnames<-c("river", "lifestage", "lifestage.river", "intercept")
print(aictab(cand.set=Cand.models, modnames=Modnames, sort=T), digits=4, LL=T)

##########
#Brute force AIC table to check package.
output<-matrix(nrow=4, ncol=5)
rownames(output)<-c("GLM_1", "GLM_2", "GLM_3", "GLM_4")
colnames(output)<-c("AIC", "DevianceExpl", "LogLik",  "Delta AIC", "Aikaike weights")
head(output)

#Extract AIC
output[1,1]<- (AIC(GLM_1))
output[2,1]<-(AIC(GLM_2))
output[3,1]<-(AIC(GLM_3))
output[4,1]<-(AIC(GLM_4))
#Extract Deviance explained

output[1,2]<-((GLM_1$null.deviance-GLM_1$deviance)/GLM_1$null.deviance)*100
output[2,2]<-((GLM_2$null.deviance-GLM_2$deviance)/GLM_2$null.deviance)*100
output[3,2]<-((GLM_3$null.deviance-GLM_3$deviance)/GLM_3$null.deviance)*100
output[4,2]<-((GLM_4$null.deviance-GLM_4$deviance)/GLM_4$null.deviance)*100
#Extract Log liklihood, which is similar to AIC but not weighted by number of parameters

output[1,3]<-logLik(GLM_1)[1]
output[2,3]<-logLik(GLM_2)[1]
output[3,3]<-logLik(GLM_3)[1]
output[4,3]<-logLik(GLM_4)[1]

#Goodness of fit measures

#Delta AIC, adjusts AIC such that the top model AIC = 0 and other models are rescaled.
output[1,4]<-AIC(GLM_1) - min(output[,1])
output[2,4]<-AIC(GLM_2) - min(output[,1])
output[3,4]<-AIC(GLM_3) - min(output[,1])
output[4,4]<-AIC(GLM_4) - min(output[,1])

#Akaike weights --> the probability that model i is the best model in the set.
#Calculated as (exp(-0.5*deltaAICi))/sum of all(exp(0.5*deltaAIC))
#First, calculate sum of exp(-0.5*deltaAIC)
sum<-(exp(-0.5*output[1,4])+exp(-0.5*output[2,4])+exp(-0.5*output[3,4])+exp(-0.5*output[4,4]))

output[1,5]<-exp(-0.5*output[1,4])/sum
output[2,5]<-exp(-0.5*output[2,4])/sum
output[3,5]<-exp(-0.5*output[3,4])/sum
output[4,5]<-exp(-0.5*output[4,4])/sum

output

write.table(output, file="")
#DONE


###################################################################################
#Effect Sizes
#Calculates the % difference between the various life stages; adult v kelt, adult v. smolt, kelt v smolt.
#% difference calculated as column-row/row

#Subset data by life stage
smolt<-subset(macropanel, life.stage=="3")
kelt<-subset(macropanel, life.stage=="2")
adult<-subset(macropanel, life.stage=="1")

#Create matrix of means
ls.means<-matrix(nrow=3, ncol=2)
rownames(ls.means)<-c("Adult", "Kelt", "Smolt")
colnames(ls.means)<-c("% P", "STDEV")
head(ls.means)

#Calculate means for each life stage across rivers (i.e., all rivers pooled)
ls.means[3,1]<-mean(smolt$p, na.rm=T)
ls.means[2,1]<-mean(kelt$p, na.rm=T)
ls.means[1,1]<-mean(adult$p, na.rm=T)

ls.means[3,2]<-sd(smolt$p, na.rm=T)
ls.means[2,2]<-sd(kelt$p, na.rm=T)
ls.means[1,2]<-sd(adult$p, na.rm=T)

ls.means

#Subset by river
cam<-subset(p.content, river=="1")
cn<-subset(p.content, river=="2")
wab<-subset(p.content, river=="3")

mean.cam<-mean(cam$p, na.rm=T)
mean.cn<-mean(cn$p, na.rm=T)
mean.wab<-mean(wab$p, na.rm=T)

#subset by river and life stage
cam.smolt<-subset(cam, life.stage=="3")
cam.kelt<-subset(cam, life.stage=="2")
cam.adult<-subset(cam, life.stage=="1")

cn.smolt<-subset(cn, life.stage=="3")
cn.kelt<-subset(cn, life.stage=="2")
cn.adult<-subset(cn, life.stage=="1")

wab.smolt<-subset(wab, life.stage=="3")
wab.kelt<-subset(wab, life.stage=="2")
wab.adult<-subset(wab, life.stage=="1")

#Calculate life stage specific means for each river rls.mean refers to river and lifestage means.
#VALUES IN THIS MATRIX ARE USED TO CALCULATE P FLUX

rls.means<-matrix(nrow=3, ncol=9)
rownames(rls.means)<-c("Campbellton", "Conne", "Western Arm")
colnames(rls.means)<-c("Adult","sd", "Kelt","sd", "Smolt", "sd", "smoltCV", "keltCV", "adultCV")
head(rls.means)

rls.means[1,5]<-mean(cam.smolt$p, na.rm=T)
rls.means[2,5]<-mean(cn.smolt$p, na.rm=T)
rls.means[3,5]<-mean(wab.smolt$p, na.rm=T)
rls.means[1,6]<-sd(cam.smolt$p, na.rm=T)
rls.means[2,6]<-sd(cn.smolt$p, na.rm=T)
rls.means[3,6]<-sd(wab.smolt$p, na.rm=T)

rls.means[1,3]<-mean(cam.kelt$p, na.rm=T)
rls.means[2,3]<-mean(cn.kelt$p, na.rm=T)
rls.means[3,3]<-mean(wab.kelt$p, na.rm=T)
rls.means[1,4]<-sd(cam.kelt$p, na.rm=T)
rls.means[2,4]<-sd(cn.kelt$p, na.rm=T)
rls.means[3,4]<-sd(wab.kelt$p, na.rm=T)

rls.means[1,1]<-mean(cam.adult$p, na.rm=T)
rls.means[2,1]<-mean(cn.adult$p, na.rm=T)
rls.means[3,1]<-mean(wab.adult$p, na.rm=T)
rls.means[1,2]<-sd(cam.adult$p, na.rm=T)
rls.means[2,2]<-sd(cn.adult$p, na.rm=T)
rls.means[3,2]<-sd(wab.adult$p, na.rm=T)

rls.means[1,9]<-sd(cam.smolt$p, na.rm=T)/mean(cam.smolt$p, na.rm=T)
rls.means[2,9]<-sd(cn.smolt$p, na.rm=T)/mean(cn.smolt$p, na.rm=T)
rls.means[3,9]<-sd(wab.smolt$p, na.rm=T)/mean(wab.smolt$p, na.rm=T)
rls.means[1,8]<-sd(cam.kelt$p, na.rm=T)/mean(cam.kelt$p, na.rm=T)
rls.means[2,8]<-sd(cn.kelt$p, na.rm=T)/mean(cn.kelt$p, na.rm=T)
rls.means[3,8]<-sd(wab.kelt$p, na.rm=T)/mean(wab.kelt$p, na.rm=T)
rls.means[1,7]<-sd(cam.adult$p, na.rm=T)/mean(cam.adult$p, na.rm=T)
rls.means[2,7]<-sd(cn.adult$p, na.rm=T)/mean(cn.adult$p, na.rm=T)
rls.means[3,7]<-sd(wab.adult$p, na.rm=T)/mean(wab.adult$p, na.rm=T)

rls.means

# Calculates % difference between life stages (pooled across rivers)

ls.diff<-matrix(nrow=3, ncol=1)
rownames(ls.diff)<-c("Adult vs. Kelt", "Adult vs. Smolt", "Kelt vs. Smolt")
colnames(ls.diff)<-c("% difference")
head(ls.diff)

ls.diff
#ordered to make output values positive. Whether a life stage is treated as expected or observed in the % difference below only affects sign of the value
ls.diff[1,1]<-((ls.means[2,1]-ls.means[1,1])/ls.means[1,1])*100
ls.diff[2,1]<-((ls.means[3,1]-ls.means[1,1])/ls.means[1,1])*100
ls.diff[3,1]<-((ls.means[3,1]-ls.means[2,1])/ls.means[2,1])*100
ls.diff
write.table(ls.diff, file="")

#Matrix of Ca:P ratios for different life stages +/- 1SD

CA.P<-matrix(nrow=2, ncol=3)
rownames(CA.P)<-c("Ca:P", "stdev")
colnames(CA.P)<-c("smolt", "adult", "kelt")

CA.P[1,1]<-mean(smolt$ratio, na.rm=T)
CA.P[1,2]<-mean(adult$ratio, na.rm=T)
CA.P[1,3]<-mean(kelt$ratio, na.rm=T)
CA.P[2,1]<-sd(smolt$ratio, na.rm=T)
CA.P[2,2]<-sd(adult$ratio, na.rm=T)
CA.P[2,3]<-sd(kelt$ratio, na.rm=T)

#plot %P vs. %Ca to determine % of P 

smolt.ca.p<-summary(lm(smolt$ca.d~smolt$p.d))
adult.ca.p<-summary(lm(adult$ca.d~adult$p.d))
kelt.ca.p<-summary(lm(kelt$ca.d~kelt$p.d))

plot(smolt$ca.d~smolt$p.d, pch=1, xlim=c(0, 4), ylim=c(0,0.5), xlab="", ylab="")
points(adult$ca.d~adult$p.d, pch=2)
points(kelt$ca.d~kelt$p.d, pch=8)
abline(smolt.ca.p)
abline(kelt.ca.p, lty="dashed")
abline(adult.ca.p, lwd=2)

#####################################################################################
#FIGURE 2 in EBEL, LEROUX, ROBERTSON, DEMPSON

data<-macropanel


options(scipen=10) # removes scientific notation from plots
x11(height=8, width=5.5)
par(mfrow=c(3,1))
par(oma=c(3,3,3,3)) #sets outer margins
par(mar=c(0,4,1,2))
par(las=1)
par(mgp=c(1, 1, 0))
#plot %P wet mass
plot(jitter(as.numeric(smolt$river)), smolt$p, main="", xlab="", ylab="", cex.lab=2, cex.main=1.75,  cex.axis=1.5, cex=2.25, xlim=c(0,4), ylim=c(0,1), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt$river)), kelt$p, pch=8,  cex=2.25, col="black")
points(jitter(as.numeric(adult$river)), adult$p, pch=2, cex=2.25, col="black")
legend("topleft", legend=c("smolt","adult", "kelt"), pch=c(1, 2, 8), pt.cex=2, cex=1.5, bty="n")

#plot %P dry mass
plot(jitter(as.numeric(smolt$river)), smolt$p.d, main="", xlab="", ylab="", cex.lab=2, cex.main=1.75,  cex.axis=1.5, cex=2.25, xlim=c(0,4), ylim=c(0,4), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt$river)), kelt$p.d, pch=8, cex=2.25, col="black")
points(jitter(as.numeric(adult$river)), adult$p.d, pch=2, cex=2.25, col="black")

#Plot % dry weight
plot(jitter(as.numeric(smolt$river)), smolt$ratio, main="", xlab="", ylab="", cex.lab=2, cex.main=1.75,  cex.axis=1.5, cex=2.25, xlim=c(0,4), ylim=c(0, 1.5), pch=1, col="black", xaxt="n")
points(jitter(as.numeric(kelt$river)), kelt$ratio, pch=8, cex=2.25, col="black")
points(jitter(as.numeric(adult$river)), adult$ratio, pch=2, cex=2.25, col="black")

#add river names as labels
mtext(c("Campbellton"), srt=45, cex=1.75, side=1, line=1, at=c(1))
mtext(c("Conne"), srt=45,cex=1.75, side=1, line=1, at=c(2))
mtext(c("Western Arm"), srt=45, cex=1.75, side=1, line=1, at=c(3))

######################################################################################################################################################################

#This section of code summarizes adult weights measured annually over a 20 year period. Data is contained in now contained in adult.weight.csv and the imported file should be updated accordingly
#The matrices produced in these tables are merged into the dataframe for calculating flux. 


#figshare datafile name: adult.weights.csv

head(adult.weights)
data<-adult.weights

small<-subset(data, ls=="3")
large<-subset(data, ls=="4")

rm(data)

data<-small
cam.s<-subset(data, strm=="CAM")
cn.s<-subset(data, strm=="CN")
wab.s<-subset(data, strm=="WAB")

rm(data)

data<-large

cam.l<-subset(data, strm=="CAM")
cn.l<-subset(data, strm=="CN")
wab.l<-subset(data, strm=="WAB")

rm(data)

#make a matrix that includes mean weights of large and small spawners
data<-cam.s
ww<-matrix(nrow=20, ncol=4)
colnames(ww)<-c("yr", "mean", "sd", "n")

ww[1,1]<-1993;ww[1,2]<-mean(subset(data$ww, data$yr=="1993")); ww[1,3]<-sd(subset(data$ww, data$yr=="1993")); ww[1,4]<-nrow(subset(data, yr=="1993"))
ww[2,1]<-1994;ww[2,2]<-mean(subset(data$ww, data$yr=="1994")); ww[2,3]<-sd(subset(data$ww, data$yr=="1994")); ww[2,4]<-nrow(subset(data, yr=="1994"))
ww[3,1]<-1995;ww[3,2]<-mean(subset(data$ww, data$yr=="1995")); ww[3,3]<-sd(subset(data$ww, data$yr=="1995")); ww[3,4]<-nrow(subset(data, yr=="1995"))
ww[4,1]<-1996;ww[4,2]<-mean(subset(data$ww, data$yr=="1996")); ww[4,3]<-sd(subset(data$ww, data$yr=="1996")); ww[4,4]<-nrow(subset(data, yr=="1996"))
ww[5,1]<-1997;ww[5,2]<-mean(subset(data$ww, data$yr=="1997")); ww[5,3]<-sd(subset(data$ww, data$yr=="1997")); ww[5,4]<-nrow(subset(data, yr=="1997"))
ww[6,1]<-1998;ww[6,2]<-mean(subset(data$ww, data$yr=="1998")); ww[6,3]<-sd(subset(data$ww, data$yr=="1998")); ww[6,4]<-nrow(subset(data, yr=="1998"))
ww[7,1]<-1999;ww[7,2]<-mean(subset(data$ww, data$yr=="1999")); ww[7,3]<-sd(subset(data$ww, data$yr=="1999")); ww[7,4]<-nrow(subset(data, yr=="1999"))
ww[8,1]<-2000;ww[8,2]<-mean(subset(data$ww, data$yr=="2000")); ww[8,3]<-sd(subset(data$ww, data$yr=="2000")); ww[8,4]<-nrow(subset(data, yr=="2000"))
ww[9,1]<-2001;ww[9,2]<-mean(subset(data$ww, data$yr=="2001")); ww[9,3]<-sd(subset(data$ww, data$yr=="2001")); ww[9,4]<-nrow(subset(data, yr=="2001"))
ww[10,1]<-2002;ww[10,2]<-mean(subset(data$ww, data$yr=="2002")); ww[10,3]<-sd(subset(data$ww, data$yr=="2002")); ww[10,4]<-nrow(subset(data, yr=="2002"))
ww[11,1]<-2003;ww[11,2]<-mean(subset(data$ww, data$yr=="2003")); ww[11,3]<-sd(subset(data$ww, data$yr=="2003")); ww[11,4]<-nrow(subset(data, yr=="2003"))
ww[12,1]<-2004;ww[12,2]<-mean(subset(data$ww, data$yr=="2004")); ww[12,3]<-sd(subset(data$ww, data$yr=="2004")); ww[12,4]<-nrow(subset(data, yr=="2004"))
ww[13,1]<-2005;ww[13,2]<-mean(subset(data$ww, data$yr=="2005")); ww[13,3]<-sd(subset(data$ww, data$yr=="2005")); ww[13,4]<-nrow(subset(data, yr=="2005"))
ww[14,1]<-2006;ww[14,2]<-mean(subset(data$ww, data$yr=="2006")); ww[14,3]<-sd(subset(data$ww, data$yr=="2006")); ww[14,4]<-nrow(subset(data, yr=="2006"))
ww[15,1]<-2007;ww[15,2]<-mean(subset(data$ww, data$yr=="2007")); ww[15,3]<-sd(subset(data$ww, data$yr=="2007")); ww[15,4]<-nrow(subset(data, yr=="2007"))
ww[16,1]<-2008;ww[16,2]<-mean(subset(data$ww, data$yr=="2008")); ww[16,3]<-sd(subset(data$ww, data$yr=="2008")); ww[16,4]<-nrow(subset(data, yr=="2008"))
ww[17,1]<-2009;ww[17,2]<-mean(subset(data$ww, data$yr=="2009")); ww[17,3]<-sd(subset(data$ww, data$yr=="2009")); ww[17,4]<-nrow(subset(data, yr=="2009"))
ww[18,1]<-2010;ww[18,2]<-mean(subset(data$ww, data$yr=="2010")); ww[18,3]<-sd(subset(data$ww, data$yr=="2010")); ww[18,4]<-nrow(subset(data, yr=="2010"))
ww[19,1]<-2011;ww[19,2]<-mean(subset(data$ww, data$yr=="2011")); ww[19,3]<-sd(subset(data$ww, data$yr=="2011")); ww[19,4]<-nrow(subset(data, yr=="2011"))
ww[20,1]<-2012;ww[20,2]<-mean(subset(data$ww, data$yr=="2012")); ww[20,3]<-sd(subset(data$ww, data$yr=="2012")); ww[20,4]<-nrow(subset(data, yr=="2012"))

#CAM_small mean fork lengths

fl<-matrix(nrow=20, ncol=4)
colnames(fl)<-c("yr", "mean", "sd", "n")
fl[1,1]<-1993;fl[1,2]<-mean(subset(data$fl, data$yr=="1993")); fl[1,3]<-sd(subset(data$fl, data$yr=="1993")); fl[1,4]<-nrow(subset(data, yr=="1993"))
fl[2,1]<-1994;fl[2,2]<-mean(subset(data$fl, data$yr=="1994")); fl[2,3]<-sd(subset(data$fl, data$yr=="1994")); fl[2,4]<-nrow(subset(data, yr=="1994"))
fl[3,1]<-1995;fl[3,2]<-mean(subset(data$fl, data$yr=="1995")); fl[3,3]<-sd(subset(data$fl, data$yr=="1995")); fl[3,4]<-nrow(subset(data, yr=="1995"))
fl[4,1]<-1996;fl[4,2]<-mean(subset(data$fl, data$yr=="1996")); fl[4,3]<-sd(subset(data$fl, data$yr=="1996")); fl[4,4]<-nrow(subset(data, yr=="1996"))
fl[5,1]<-1997;fl[5,2]<-mean(subset(data$fl, data$yr=="1997")); fl[5,3]<-sd(subset(data$fl, data$yr=="1997")); fl[5,4]<-nrow(subset(data, yr=="1997"))
fl[6,1]<-1998;fl[6,2]<-mean(subset(data$fl, data$yr=="1998")); fl[6,3]<-sd(subset(data$fl, data$yr=="1998")); fl[6,4]<-nrow(subset(data, yr=="1998"))
fl[7,1]<-1999;fl[7,2]<-mean(subset(data$fl, data$yr=="1999")); fl[7,3]<-sd(subset(data$fl, data$yr=="1999")); fl[7,4]<-nrow(subset(data, yr=="1999"))
fl[8,1]<-2000;fl[8,2]<-mean(subset(data$fl, data$yr=="2000")); fl[8,3]<-sd(subset(data$fl, data$yr=="2000")); fl[8,4]<-nrow(subset(data, yr=="2000"))
fl[9,1]<-2001;fl[9,2]<-mean(subset(data$fl, data$yr=="2001")); fl[9,3]<-sd(subset(data$fl, data$yr=="2001")); fl[9,4]<-nrow(subset(data, yr=="2001"))
fl[10,1]<-2002;fl[10,2]<-mean(subset(data$fl, data$yr=="2002")); fl[10,3]<-sd(subset(data$fl, data$yr=="2002")); fl[10,4]<-nrow(subset(data, yr=="2002"))
fl[11,1]<-2003;fl[11,2]<-mean(subset(data$fl, data$yr=="2003")); fl[11,3]<-sd(subset(data$fl, data$yr=="2003")); fl[11,4]<-nrow(subset(data, yr=="2003"))
fl[12,1]<-2004;fl[12,2]<-mean(subset(data$fl, data$yr=="2004")); fl[12,3]<-sd(subset(data$fl, data$yr=="2004")); fl[12,4]<-nrow(subset(data, yr=="2004"))
fl[13,1]<-2005;fl[13,2]<-mean(subset(data$fl, data$yr=="2005")); fl[13,3]<-sd(subset(data$fl, data$yr=="2005")); fl[13,4]<-nrow(subset(data, yr=="2005"))
fl[14,1]<-2006;fl[14,2]<-mean(subset(data$fl, data$yr=="2006")); fl[14,3]<-sd(subset(data$fl, data$yr=="2006")); fl[14,4]<-nrow(subset(data, yr=="2006"))
fl[15,1]<-2007;fl[15,2]<-mean(subset(data$fl, data$yr=="2007")); fl[15,3]<-sd(subset(data$fl, data$yr=="2007")); fl[15,4]<-nrow(subset(data, yr=="2007"))
fl[16,1]<-2008;fl[16,2]<-mean(subset(data$fl, data$yr=="2008")); fl[16,3]<-sd(subset(data$fl, data$yr=="2008")); fl[16,4]<-nrow(subset(data, yr=="2008"))
fl[17,1]<-2009;fl[17,2]<-mean(subset(data$fl, data$yr=="2009")); fl[17,3]<-sd(subset(data$fl, data$yr=="2009")); fl[17,4]<-nrow(subset(data, yr=="2009"))
fl[18,1]<-2010;fl[18,2]<-mean(subset(data$fl, data$yr=="2010")); fl[18,3]<-sd(subset(data$fl, data$yr=="2010")); fl[18,4]<-nrow(subset(data, yr=="2010"))
fl[19,1]<-2011;fl[19,2]<-mean(subset(data$fl, data$yr=="2011")); fl[19,3]<-sd(subset(data$fl, data$yr=="2011")); fl[19,4]<-nrow(subset(data, yr=="2011"))
fl[20,1]<-2012;fl[20,2]<-mean(subset(data$fl, data$yr=="2012")); fl[20,3]<-sd(subset(data$fl, data$yr=="2012")); fl[20,4]<-nrow(subset(data, yr=="2012"))

cam.s.fl<-fl
rm(fl)

cam.s.ww<-ww
rm(ww)

rm(data)
####CAMPBELLTON LARGE SALMON
data<-cam.l

ww<-matrix(nrow=20, ncol=4)
colnames(ww)<-c("yr", "mean", "sd", "n")

ww[1,1]<-1993;ww[1,2]<-mean(subset(data$ww, data$yr=="1993")); ww[1,3]<-sd(subset(data$ww, data$yr=="1993")); ww[1,4]<-nrow(subset(data, yr=="1993"))
ww[2,1]<-1994;ww[2,2]<-mean(subset(data$ww, data$yr=="1994")); ww[2,3]<-sd(subset(data$ww, data$yr=="1994")); ww[2,4]<-nrow(subset(data, yr=="1994"))
ww[3,1]<-1995;ww[3,2]<-mean(subset(data$ww, data$yr=="1995")); ww[3,3]<-sd(subset(data$ww, data$yr=="1995")); ww[3,4]<-nrow(subset(data, yr=="1995"))
ww[4,1]<-1996;ww[4,2]<-mean(subset(data$ww, data$yr=="1996")); ww[4,3]<-sd(subset(data$ww, data$yr=="1996")); ww[4,4]<-nrow(subset(data, yr=="1996"))
ww[5,1]<-1997;ww[5,2]<-mean(subset(data$ww, data$yr=="1997")); ww[5,3]<-sd(subset(data$ww, data$yr=="1997")); ww[5,4]<-nrow(subset(data, yr=="1997"))
ww[6,1]<-1998;ww[6,2]<-mean(subset(data$ww, data$yr=="1998")); ww[6,3]<-sd(subset(data$ww, data$yr=="1998")); ww[6,4]<-nrow(subset(data, yr=="1998"))
ww[7,1]<-1999;ww[7,2]<-mean(subset(data$ww, data$yr=="1999")); ww[7,3]<-sd(subset(data$ww, data$yr=="1999")); ww[7,4]<-nrow(subset(data, yr=="1999"))
ww[8,1]<-2000;ww[8,2]<-mean(subset(data$ww, data$yr=="2000")); ww[8,3]<-sd(subset(data$ww, data$yr=="2000")); ww[8,4]<-nrow(subset(data, yr=="2000"))
ww[9,1]<-2001;ww[9,2]<-mean(subset(data$ww, data$yr=="2001")); ww[9,3]<-sd(subset(data$ww, data$yr=="2001")); ww[9,4]<-nrow(subset(data, yr=="2001"))
ww[10,1]<-2002;ww[10,2]<-mean(subset(data$ww, data$yr=="2002")); ww[10,3]<-sd(subset(data$ww, data$yr=="2002")); ww[10,4]<-nrow(subset(data, yr=="2002"))
ww[11,1]<-2003;ww[11,2]<-mean(subset(data$ww, data$yr=="2003")); ww[11,3]<-sd(subset(data$ww, data$yr=="2003")); ww[11,4]<-nrow(subset(data, yr=="2003"))
ww[12,1]<-2004;ww[12,2]<-mean(subset(data$ww, data$yr=="2004")); ww[12,3]<-sd(subset(data$ww, data$yr=="2004")); ww[12,4]<-nrow(subset(data, yr=="2004"))
ww[13,1]<-2005;ww[13,2]<-mean(subset(data$ww, data$yr=="2005")); ww[13,3]<-sd(subset(data$ww, data$yr=="2005")); ww[13,4]<-nrow(subset(data, yr=="2005"))
ww[14,1]<-2006;ww[14,2]<-mean(subset(data$ww, data$yr=="2006")); ww[14,3]<-sd(subset(data$ww, data$yr=="2006")); ww[14,4]<-nrow(subset(data, yr=="2006"))
ww[15,1]<-2007;ww[15,2]<-mean(subset(data$ww, data$yr=="2007")); ww[15,3]<-sd(subset(data$ww, data$yr=="2007")); ww[15,4]<-nrow(subset(data, yr=="2007"))
ww[16,1]<-2008;ww[16,2]<-mean(subset(data$ww, data$yr=="2008")); ww[16,3]<-sd(subset(data$ww, data$yr=="2008")); ww[16,4]<-nrow(subset(data, yr=="2008"))
ww[17,1]<-2009;ww[17,2]<-mean(subset(data$ww, data$yr=="2009")); ww[17,3]<-sd(subset(data$ww, data$yr=="2009")); ww[17,4]<-nrow(subset(data, yr=="2009"))
ww[18,1]<-2010;ww[18,2]<-mean(subset(data$ww, data$yr=="2010")); ww[18,3]<-sd(subset(data$ww, data$yr=="2010")); ww[18,4]<-nrow(subset(data, yr=="2010"))
ww[19,1]<-2011;ww[19,2]<-mean(subset(data$ww, data$yr=="2011")); ww[19,3]<-sd(subset(data$ww, data$yr=="2011")); ww[19,4]<-nrow(subset(data, yr=="2011"))
ww[20,1]<-2012;ww[20,2]<-mean(subset(data$ww, data$yr=="2012")); ww[20,3]<-sd(subset(data$ww, data$yr=="2012")); ww[20,4]<-nrow(subset(data, yr=="2012"))

#CAM_large mean fork lengths

fl<-matrix(nrow=20, ncol=4)
colnames(fl)<-c("yr", "mean", "sd", "n")
fl[1,1]<-1993;fl[1,2]<-mean(subset(data$fl, data$yr=="1993")); fl[1,3]<-sd(subset(data$fl, data$yr=="1993")); fl[1,4]<-nrow(subset(data, yr=="1993"))
fl[2,1]<-1994;fl[2,2]<-mean(subset(data$fl, data$yr=="1994")); fl[2,3]<-sd(subset(data$fl, data$yr=="1994")); fl[2,4]<-nrow(subset(data, yr=="1994"))
fl[3,1]<-1995;fl[3,2]<-mean(subset(data$fl, data$yr=="1995")); fl[3,3]<-sd(subset(data$fl, data$yr=="1995")); fl[3,4]<-nrow(subset(data, yr=="1995"))
fl[4,1]<-1996;fl[4,2]<-mean(subset(data$fl, data$yr=="1996")); fl[4,3]<-sd(subset(data$fl, data$yr=="1996")); fl[4,4]<-nrow(subset(data, yr=="1996"))
fl[5,1]<-1997;fl[5,2]<-mean(subset(data$fl, data$yr=="1997")); fl[5,3]<-sd(subset(data$fl, data$yr=="1997")); fl[5,4]<-nrow(subset(data, yr=="1997"))
fl[6,1]<-1998;fl[6,2]<-mean(subset(data$fl, data$yr=="1998")); fl[6,3]<-sd(subset(data$fl, data$yr=="1998")); fl[6,4]<-nrow(subset(data, yr=="1998"))
fl[7,1]<-1999;fl[7,2]<-mean(subset(data$fl, data$yr=="1999")); fl[7,3]<-sd(subset(data$fl, data$yr=="1999")); fl[7,4]<-nrow(subset(data, yr=="1999"))
fl[8,1]<-2000;fl[8,2]<-mean(subset(data$fl, data$yr=="2000")); fl[8,3]<-sd(subset(data$fl, data$yr=="2000")); fl[8,4]<-nrow(subset(data, yr=="2000"))
fl[9,1]<-2001;fl[9,2]<-mean(subset(data$fl, data$yr=="2001")); fl[9,3]<-sd(subset(data$fl, data$yr=="2001")); fl[9,4]<-nrow(subset(data, yr=="2001"))
fl[10,1]<-2002;fl[10,2]<-mean(subset(data$fl, data$yr=="2002")); fl[10,3]<-sd(subset(data$fl, data$yr=="2002")); fl[10,4]<-nrow(subset(data, yr=="2002"))
fl[11,1]<-2003;fl[11,2]<-mean(subset(data$fl, data$yr=="2003")); fl[11,3]<-sd(subset(data$fl, data$yr=="2003")); fl[11,4]<-nrow(subset(data, yr=="2003"))
fl[12,1]<-2004;fl[12,2]<-mean(subset(data$fl, data$yr=="2004")); fl[12,3]<-sd(subset(data$fl, data$yr=="2004")); fl[12,4]<-nrow(subset(data, yr=="2004"))
fl[13,1]<-2005;fl[13,2]<-mean(subset(data$fl, data$yr=="2005")); fl[13,3]<-sd(subset(data$fl, data$yr=="2005")); fl[13,4]<-nrow(subset(data, yr=="2005"))
fl[14,1]<-2006;fl[14,2]<-mean(subset(data$fl, data$yr=="2006")); fl[14,3]<-sd(subset(data$fl, data$yr=="2006")); fl[14,4]<-nrow(subset(data, yr=="2006"))
fl[15,1]<-2007;fl[15,2]<-mean(subset(data$fl, data$yr=="2007")); fl[15,3]<-sd(subset(data$fl, data$yr=="2007")); fl[15,4]<-nrow(subset(data, yr=="2007"))
fl[16,1]<-2008;fl[16,2]<-mean(subset(data$fl, data$yr=="2008")); fl[16,3]<-sd(subset(data$fl, data$yr=="2008")); fl[16,4]<-nrow(subset(data, yr=="2008"))
fl[17,1]<-2009;fl[17,2]<-mean(subset(data$fl, data$yr=="2009")); fl[17,3]<-sd(subset(data$fl, data$yr=="2009")); fl[17,4]<-nrow(subset(data, yr=="2009"))
fl[18,1]<-2010;fl[18,2]<-mean(subset(data$fl, data$yr=="2010")); fl[18,3]<-sd(subset(data$fl, data$yr=="2010")); fl[18,4]<-nrow(subset(data, yr=="2010"))
fl[19,1]<-2011;fl[19,2]<-mean(subset(data$fl, data$yr=="2011")); fl[19,3]<-sd(subset(data$fl, data$yr=="2011")); fl[19,4]<-nrow(subset(data, yr=="2011"))
fl[20,1]<-2012;fl[20,2]<-mean(subset(data$fl, data$yr=="2012")); fl[20,3]<-sd(subset(data$fl, data$yr=="2012")); fl[20,4]<-nrow(subset(data, yr=="2012"))

cam.l.fl<-fl
rm(fl)

cam.l.ww<-ww
rm(ww)

rm(data)
###########################################################################################################################
#Conne 
data<-cn.s


#make a matrix that includes mean weights of large and small spawners
data<-cn.s
ww<-matrix(nrow=20, ncol=4)
colnames(ww)<-c("yr", "mean", "sd", "n")

ww[1,1]<-1993;ww[1,2]<-mean(subset(data$ww, data$yr=="1993")); ww[1,3]<-sd(subset(data$ww, data$yr=="1993")); ww[1,4]<-nrow(subset(data, yr=="1993"))
ww[2,1]<-1994;ww[2,2]<-mean(subset(data$ww, data$yr=="1994")); ww[2,3]<-sd(subset(data$ww, data$yr=="1994")); ww[2,4]<-nrow(subset(data, yr=="1994"))
ww[3,1]<-1995;ww[3,2]<-mean(subset(data$ww, data$yr=="1995")); ww[3,3]<-sd(subset(data$ww, data$yr=="1995")); ww[3,4]<-nrow(subset(data, yr=="1995"))
ww[4,1]<-1996;ww[4,2]<-mean(subset(data$ww, data$yr=="1996")); ww[4,3]<-sd(subset(data$ww, data$yr=="1996")); ww[4,4]<-nrow(subset(data, yr=="1996"))
ww[5,1]<-1997;ww[5,2]<-mean(subset(data$ww, data$yr=="1997")); ww[5,3]<-sd(subset(data$ww, data$yr=="1997")); ww[5,4]<-nrow(subset(data, yr=="1997"))
ww[6,1]<-1998;ww[6,2]<-mean(subset(data$ww, data$yr=="1998")); ww[6,3]<-sd(subset(data$ww, data$yr=="1998")); ww[6,4]<-nrow(subset(data, yr=="1998"))
ww[7,1]<-1999;ww[7,2]<-mean(subset(data$ww, data$yr=="1999")); ww[7,3]<-sd(subset(data$ww, data$yr=="1999")); ww[7,4]<-nrow(subset(data, yr=="1999"))
ww[8,1]<-2000;ww[8,2]<-mean(subset(data$ww, data$yr=="2000")); ww[8,3]<-sd(subset(data$ww, data$yr=="2000")); ww[8,4]<-nrow(subset(data, yr=="2000"))
ww[9,1]<-2001;ww[9,2]<-mean(subset(data$ww, data$yr=="2001")); ww[9,3]<-sd(subset(data$ww, data$yr=="2001")); ww[9,4]<-nrow(subset(data, yr=="2001"))
ww[10,1]<-2002;ww[10,2]<-mean(subset(data$ww, data$yr=="2002")); ww[10,3]<-sd(subset(data$ww, data$yr=="2002")); ww[10,4]<-nrow(subset(data, yr=="2002"))
ww[11,1]<-2003;ww[11,2]<-mean(subset(data$ww, data$yr=="2003")); ww[11,3]<-sd(subset(data$ww, data$yr=="2003")); ww[11,4]<-nrow(subset(data, yr=="2003"))
ww[12,1]<-2004;ww[12,2]<-mean(subset(data$ww, data$yr=="2004")); ww[12,3]<-sd(subset(data$ww, data$yr=="2004")); ww[12,4]<-nrow(subset(data, yr=="2004"))
ww[13,1]<-2005;ww[13,2]<-mean(subset(data$ww, data$yr=="2005")); ww[13,3]<-sd(subset(data$ww, data$yr=="2005")); ww[13,4]<-nrow(subset(data, yr=="2005"))
ww[14,1]<-2006;ww[14,2]<-mean(subset(data$ww, data$yr=="2006")); ww[14,3]<-sd(subset(data$ww, data$yr=="2006")); ww[14,4]<-nrow(subset(data, yr=="2006"))
ww[15,1]<-2007;ww[15,2]<-mean(subset(data$ww, data$yr=="2007")); ww[15,3]<-sd(subset(data$ww, data$yr=="2007")); ww[15,4]<-nrow(subset(data, yr=="2007"))
ww[16,1]<-2008;ww[16,2]<-mean(subset(data$ww, data$yr=="2008")); ww[16,3]<-sd(subset(data$ww, data$yr=="2008")); ww[16,4]<-nrow(subset(data, yr=="2008"))
ww[17,1]<-2009;ww[17,2]<-mean(subset(data$ww, data$yr=="2009")); ww[17,3]<-sd(subset(data$ww, data$yr=="2009")); ww[17,4]<-nrow(subset(data, yr=="2009"))
ww[18,1]<-2010;ww[18,2]<-mean(subset(data$ww, data$yr=="2010")); ww[18,3]<-sd(subset(data$ww, data$yr=="2010")); ww[18,4]<-nrow(subset(data, yr=="2010"))
ww[19,1]<-2011;ww[19,2]<-mean(subset(data$ww, data$yr=="2011")); ww[19,3]<-sd(subset(data$ww, data$yr=="2011")); ww[19,4]<-nrow(subset(data, yr=="2011"))
ww[20,1]<-2012;ww[20,2]<-mean(subset(data$ww, data$yr=="2012")); ww[20,3]<-sd(subset(data$ww, data$yr=="2012")); ww[20,4]<-nrow(subset(data, yr=="2012"))

#CN_small mean fork lengths

fl<-matrix(nrow=20, ncol=4)
colnames(fl)<-c("yr", "mean", "sd", "n")
fl[1,1]<-1993;fl[1,2]<-mean(subset(data$fl, data$yr=="1993")); fl[1,3]<-sd(subset(data$fl, data$yr=="1993")); fl[1,4]<-nrow(subset(data, yr=="1993"))
fl[2,1]<-1994;fl[2,2]<-mean(subset(data$fl, data$yr=="1994")); fl[2,3]<-sd(subset(data$fl, data$yr=="1994")); fl[2,4]<-nrow(subset(data, yr=="1994"))
fl[3,1]<-1995;fl[3,2]<-mean(subset(data$fl, data$yr=="1995")); fl[3,3]<-sd(subset(data$fl, data$yr=="1995")); fl[3,4]<-nrow(subset(data, yr=="1995"))
fl[4,1]<-1996;fl[4,2]<-mean(subset(data$fl, data$yr=="1996")); fl[4,3]<-sd(subset(data$fl, data$yr=="1996")); fl[4,4]<-nrow(subset(data, yr=="1996"))
fl[5,1]<-1997;fl[5,2]<-mean(subset(data$fl, data$yr=="1997")); fl[5,3]<-sd(subset(data$fl, data$yr=="1997")); fl[5,4]<-nrow(subset(data, yr=="1997"))
fl[6,1]<-1998;fl[6,2]<-mean(subset(data$fl, data$yr=="1998")); fl[6,3]<-sd(subset(data$fl, data$yr=="1998")); fl[6,4]<-nrow(subset(data, yr=="1998"))
fl[7,1]<-1999;fl[7,2]<-mean(subset(data$fl, data$yr=="1999")); fl[7,3]<-sd(subset(data$fl, data$yr=="1999")); fl[7,4]<-nrow(subset(data, yr=="1999"))
fl[8,1]<-2000;fl[8,2]<-mean(subset(data$fl, data$yr=="2000")); fl[8,3]<-sd(subset(data$fl, data$yr=="2000")); fl[8,4]<-nrow(subset(data, yr=="2000"))
fl[9,1]<-2001;fl[9,2]<-mean(subset(data$fl, data$yr=="2001")); fl[9,3]<-sd(subset(data$fl, data$yr=="2001")); fl[9,4]<-nrow(subset(data, yr=="2001"))
fl[10,1]<-2002;fl[10,2]<-mean(subset(data$fl, data$yr=="2002")); fl[10,3]<-sd(subset(data$fl, data$yr=="2002")); fl[10,4]<-nrow(subset(data, yr=="2002"))
fl[11,1]<-2003;fl[11,2]<-mean(subset(data$fl, data$yr=="2003")); fl[11,3]<-sd(subset(data$fl, data$yr=="2003")); fl[11,4]<-nrow(subset(data, yr=="2003"))
fl[12,1]<-2004;fl[12,2]<-mean(subset(data$fl, data$yr=="2004")); fl[12,3]<-sd(subset(data$fl, data$yr=="2004")); fl[12,4]<-nrow(subset(data, yr=="2004"))
fl[13,1]<-2005;fl[13,2]<-mean(subset(data$fl, data$yr=="2005")); fl[13,3]<-sd(subset(data$fl, data$yr=="2005")); fl[13,4]<-nrow(subset(data, yr=="2005"))
fl[14,1]<-2006;fl[14,2]<-mean(subset(data$fl, data$yr=="2006")); fl[14,3]<-sd(subset(data$fl, data$yr=="2006")); fl[14,4]<-nrow(subset(data, yr=="2006"))
fl[15,1]<-2007;fl[15,2]<-mean(subset(data$fl, data$yr=="2007")); fl[15,3]<-sd(subset(data$fl, data$yr=="2007")); fl[15,4]<-nrow(subset(data, yr=="2007"))
fl[16,1]<-2008;fl[16,2]<-mean(subset(data$fl, data$yr=="2008")); fl[16,3]<-sd(subset(data$fl, data$yr=="2008")); fl[16,4]<-nrow(subset(data, yr=="2008"))
fl[17,1]<-2009;fl[17,2]<-mean(subset(data$fl, data$yr=="2009")); fl[17,3]<-sd(subset(data$fl, data$yr=="2009")); fl[17,4]<-nrow(subset(data, yr=="2009"))
fl[18,1]<-2010;fl[18,2]<-mean(subset(data$fl, data$yr=="2010")); fl[18,3]<-sd(subset(data$fl, data$yr=="2010")); fl[18,4]<-nrow(subset(data, yr=="2010"))
fl[19,1]<-2011;fl[19,2]<-mean(subset(data$fl, data$yr=="2011")); fl[19,3]<-sd(subset(data$fl, data$yr=="2011")); fl[19,4]<-nrow(subset(data, yr=="2011"))
fl[20,1]<-2012;fl[20,2]<-mean(subset(data$fl, data$yr=="2012")); fl[20,3]<-sd(subset(data$fl, data$yr=="2012")); fl[20,4]<-nrow(subset(data, yr=="2012"))

cn.s.fl<-fl
rm(fl)

cn.s.ww<-ww
rm(ww)

rm(data)
####Conne LARGE SALMON
data<-cn.l

ww<-matrix(nrow=20, ncol=4)
colnames(ww)<-c("yr", "mean", "sd", "n")

ww[1,1]<-1993;ww[1,2]<-mean(subset(data$ww, data$yr=="1993")); ww[1,3]<-sd(subset(data$ww, data$yr=="1993")); ww[1,4]<-nrow(subset(data, yr=="1993"))
ww[2,1]<-1994;ww[2,2]<-mean(subset(data$ww, data$yr=="1994")); ww[2,3]<-sd(subset(data$ww, data$yr=="1994")); ww[2,4]<-nrow(subset(data, yr=="1994"))
ww[3,1]<-1995;ww[3,2]<-mean(subset(data$ww, data$yr=="1995")); ww[3,3]<-sd(subset(data$ww, data$yr=="1995")); ww[3,4]<-nrow(subset(data, yr=="1995"))
ww[4,1]<-1996;ww[4,2]<-mean(subset(data$ww, data$yr=="1996")); ww[4,3]<-sd(subset(data$ww, data$yr=="1996")); ww[4,4]<-nrow(subset(data, yr=="1996"))
ww[5,1]<-1997;ww[5,2]<-mean(subset(data$ww, data$yr=="1997")); ww[5,3]<-sd(subset(data$ww, data$yr=="1997")); ww[5,4]<-nrow(subset(data, yr=="1997"))
ww[6,1]<-1998;ww[6,2]<-mean(subset(data$ww, data$yr=="1998")); ww[6,3]<-sd(subset(data$ww, data$yr=="1998")); ww[6,4]<-nrow(subset(data, yr=="1998"))
ww[7,1]<-1999;ww[7,2]<-mean(subset(data$ww, data$yr=="1999")); ww[7,3]<-sd(subset(data$ww, data$yr=="1999")); ww[7,4]<-nrow(subset(data, yr=="1999"))
ww[8,1]<-2000;ww[8,2]<-mean(subset(data$ww, data$yr=="2000")); ww[8,3]<-sd(subset(data$ww, data$yr=="2000")); ww[8,4]<-nrow(subset(data, yr=="2000"))
ww[9,1]<-2001;ww[9,2]<-mean(subset(data$ww, data$yr=="2001")); ww[9,3]<-sd(subset(data$ww, data$yr=="2001")); ww[9,4]<-nrow(subset(data, yr=="2001"))
ww[10,1]<-2002;ww[10,2]<-mean(subset(data$ww, data$yr=="2002")); ww[10,3]<-sd(subset(data$ww, data$yr=="2002")); ww[10,4]<-nrow(subset(data, yr=="2002"))
ww[11,1]<-2003;ww[11,2]<-mean(subset(data$ww, data$yr=="2003")); ww[11,3]<-sd(subset(data$ww, data$yr=="2003")); ww[11,4]<-nrow(subset(data, yr=="2003"))
ww[12,1]<-2004;ww[12,2]<-mean(subset(data$ww, data$yr=="2004")); ww[12,3]<-sd(subset(data$ww, data$yr=="2004")); ww[12,4]<-nrow(subset(data, yr=="2004"))
ww[13,1]<-2005;ww[13,2]<-mean(subset(data$ww, data$yr=="2005")); ww[13,3]<-sd(subset(data$ww, data$yr=="2005")); ww[13,4]<-nrow(subset(data, yr=="2005"))
ww[14,1]<-2006;ww[14,2]<-mean(subset(data$ww, data$yr=="2006")); ww[14,3]<-sd(subset(data$ww, data$yr=="2006")); ww[14,4]<-nrow(subset(data, yr=="2006"))
ww[15,1]<-2007;ww[15,2]<-mean(subset(data$ww, data$yr=="2007")); ww[15,3]<-sd(subset(data$ww, data$yr=="2007")); ww[15,4]<-nrow(subset(data, yr=="2007"))
ww[16,1]<-2008;ww[16,2]<-mean(subset(data$ww, data$yr=="2008")); ww[16,3]<-sd(subset(data$ww, data$yr=="2008")); ww[16,4]<-nrow(subset(data, yr=="2008"))
ww[17,1]<-2009;ww[17,2]<-mean(subset(data$ww, data$yr=="2009")); ww[17,3]<-sd(subset(data$ww, data$yr=="2009")); ww[17,4]<-nrow(subset(data, yr=="2009"))
ww[18,1]<-2010;ww[18,2]<-mean(subset(data$ww, data$yr=="2010")); ww[18,3]<-sd(subset(data$ww, data$yr=="2010")); ww[18,4]<-nrow(subset(data, yr=="2010"))
ww[19,1]<-2011;ww[19,2]<-mean(subset(data$ww, data$yr=="2011")); ww[19,3]<-sd(subset(data$ww, data$yr=="2011")); ww[19,4]<-nrow(subset(data, yr=="2011"))
ww[20,1]<-2012;ww[20,2]<-mean(subset(data$ww, data$yr=="2012")); ww[20,3]<-sd(subset(data$ww, data$yr=="2012")); ww[20,4]<-nrow(subset(data, yr=="2012"))

#CN_large mean fork lengths

fl<-matrix(nrow=20, ncol=4)
colnames(fl)<-c("yr", "mean", "sd", "n")
fl[1,1]<-1993;fl[1,2]<-mean(subset(data$fl, data$yr=="1993")); fl[1,3]<-sd(subset(data$fl, data$yr=="1993")); fl[1,4]<-nrow(subset(data, yr=="1993"))
fl[2,1]<-1994;fl[2,2]<-mean(subset(data$fl, data$yr=="1994")); fl[2,3]<-sd(subset(data$fl, data$yr=="1994")); fl[2,4]<-nrow(subset(data, yr=="1994"))
fl[3,1]<-1995;fl[3,2]<-mean(subset(data$fl, data$yr=="1995")); fl[3,3]<-sd(subset(data$fl, data$yr=="1995")); fl[3,4]<-nrow(subset(data, yr=="1995"))
fl[4,1]<-1996;fl[4,2]<-mean(subset(data$fl, data$yr=="1996")); fl[4,3]<-sd(subset(data$fl, data$yr=="1996")); fl[4,4]<-nrow(subset(data, yr=="1996"))
fl[5,1]<-1997;fl[5,2]<-mean(subset(data$fl, data$yr=="1997")); fl[5,3]<-sd(subset(data$fl, data$yr=="1997")); fl[5,4]<-nrow(subset(data, yr=="1997"))
fl[6,1]<-1998;fl[6,2]<-mean(subset(data$fl, data$yr=="1998")); fl[6,3]<-sd(subset(data$fl, data$yr=="1998")); fl[6,4]<-nrow(subset(data, yr=="1998"))
fl[7,1]<-1999;fl[7,2]<-mean(subset(data$fl, data$yr=="1999")); fl[7,3]<-sd(subset(data$fl, data$yr=="1999")); fl[7,4]<-nrow(subset(data, yr=="1999"))
fl[8,1]<-2000;fl[8,2]<-mean(subset(data$fl, data$yr=="2000")); fl[8,3]<-sd(subset(data$fl, data$yr=="2000")); fl[8,4]<-nrow(subset(data, yr=="2000"))
fl[9,1]<-2001;fl[9,2]<-mean(subset(data$fl, data$yr=="2001")); fl[9,3]<-sd(subset(data$fl, data$yr=="2001")); fl[9,4]<-nrow(subset(data, yr=="2001"))
fl[10,1]<-2002;fl[10,2]<-mean(subset(data$fl, data$yr=="2002")); fl[10,3]<-sd(subset(data$fl, data$yr=="2002")); fl[10,4]<-nrow(subset(data, yr=="2002"))
fl[11,1]<-2003;fl[11,2]<-mean(subset(data$fl, data$yr=="2003")); fl[11,3]<-sd(subset(data$fl, data$yr=="2003")); fl[11,4]<-nrow(subset(data, yr=="2003"))
fl[12,1]<-2004;fl[12,2]<-mean(subset(data$fl, data$yr=="2004")); fl[12,3]<-sd(subset(data$fl, data$yr=="2004")); fl[12,4]<-nrow(subset(data, yr=="2004"))
fl[13,1]<-2005;fl[13,2]<-mean(subset(data$fl, data$yr=="2005")); fl[13,3]<-sd(subset(data$fl, data$yr=="2005")); fl[13,4]<-nrow(subset(data, yr=="2005"))
fl[14,1]<-2006;fl[14,2]<-mean(subset(data$fl, data$yr=="2006")); fl[14,3]<-sd(subset(data$fl, data$yr=="2006")); fl[14,4]<-nrow(subset(data, yr=="2006"))
fl[15,1]<-2007;fl[15,2]<-mean(subset(data$fl, data$yr=="2007")); fl[15,3]<-sd(subset(data$fl, data$yr=="2007")); fl[15,4]<-nrow(subset(data, yr=="2007"))
fl[16,1]<-2008;fl[16,2]<-mean(subset(data$fl, data$yr=="2008")); fl[16,3]<-sd(subset(data$fl, data$yr=="2008")); fl[16,4]<-nrow(subset(data, yr=="2008"))
fl[17,1]<-2009;fl[17,2]<-mean(subset(data$fl, data$yr=="2009")); fl[17,3]<-sd(subset(data$fl, data$yr=="2009")); fl[17,4]<-nrow(subset(data, yr=="2009"))
fl[18,1]<-2010;fl[18,2]<-mean(subset(data$fl, data$yr=="2010")); fl[18,3]<-sd(subset(data$fl, data$yr=="2010")); fl[18,4]<-nrow(subset(data, yr=="2010"))
fl[19,1]<-2011;fl[19,2]<-mean(subset(data$fl, data$yr=="2011")); fl[19,3]<-sd(subset(data$fl, data$yr=="2011")); fl[19,4]<-nrow(subset(data, yr=="2011"))
fl[20,1]<-2012;fl[20,2]<-mean(subset(data$fl, data$yr=="2012")); fl[20,3]<-sd(subset(data$fl, data$yr=="2012")); fl[20,4]<-nrow(subset(data, yr=="2012"))

cn.l.fl<-fl
rm(fl)

cn.l.ww<-ww
rm(ww)

rm(data)
##############################################################################################################################################################
#Western Arm

#make a matrix that includes mean weights of large and small spawners
data<-wab.s
ww<-matrix(nrow=20, ncol=4)
colnames(ww)<-c("yr", "mean", "sd", "n")

ww[1,1]<-1993;ww[1,2]<-mean(subset(data$ww, data$yr=="1993")); ww[1,3]<-sd(subset(data$ww, data$yr=="1993")); ww[1,4]<-nrow(subset(data, yr=="1993"))
ww[2,1]<-1994;ww[2,2]<-mean(subset(data$ww, data$yr=="1994")); ww[2,3]<-sd(subset(data$ww, data$yr=="1994")); ww[2,4]<-nrow(subset(data, yr=="1994"))
ww[3,1]<-1995;ww[3,2]<-mean(subset(data$ww, data$yr=="1995")); ww[3,3]<-sd(subset(data$ww, data$yr=="1995")); ww[3,4]<-nrow(subset(data, yr=="1995"))
ww[4,1]<-1996;ww[4,2]<-mean(subset(data$ww, data$yr=="1996")); ww[4,3]<-sd(subset(data$ww, data$yr=="1996")); ww[4,4]<-nrow(subset(data, yr=="1996"))
ww[5,1]<-1997;ww[5,2]<-mean(subset(data$ww, data$yr=="1997")); ww[5,3]<-sd(subset(data$ww, data$yr=="1997")); ww[5,4]<-nrow(subset(data, yr=="1997"))
ww[6,1]<-1998;ww[6,2]<-mean(subset(data$ww, data$yr=="1998")); ww[6,3]<-sd(subset(data$ww, data$yr=="1998")); ww[6,4]<-nrow(subset(data, yr=="1998"))
ww[7,1]<-1999;ww[7,2]<-mean(subset(data$ww, data$yr=="1999")); ww[7,3]<-sd(subset(data$ww, data$yr=="1999")); ww[7,4]<-nrow(subset(data, yr=="1999"))
ww[8,1]<-2000;ww[8,2]<-mean(subset(data$ww, data$yr=="2000")); ww[8,3]<-sd(subset(data$ww, data$yr=="2000")); ww[8,4]<-nrow(subset(data, yr=="2000"))
ww[9,1]<-2001;ww[9,2]<-mean(subset(data$ww, data$yr=="2001")); ww[9,3]<-sd(subset(data$ww, data$yr=="2001")); ww[9,4]<-nrow(subset(data, yr=="2001"))
ww[10,1]<-2002;ww[10,2]<-mean(subset(data$ww, data$yr=="2002")); ww[10,3]<-sd(subset(data$ww, data$yr=="2002")); ww[10,4]<-nrow(subset(data, yr=="2002"))
ww[11,1]<-2003;ww[11,2]<-mean(subset(data$ww, data$yr=="2003")); ww[11,3]<-sd(subset(data$ww, data$yr=="2003")); ww[11,4]<-nrow(subset(data, yr=="2003"))
ww[12,1]<-2004;ww[12,2]<-mean(subset(data$ww, data$yr=="2004")); ww[12,3]<-sd(subset(data$ww, data$yr=="2004")); ww[12,4]<-nrow(subset(data, yr=="2004"))
ww[13,1]<-2005;ww[13,2]<-mean(subset(data$ww, data$yr=="2005")); ww[13,3]<-sd(subset(data$ww, data$yr=="2005")); ww[13,4]<-nrow(subset(data, yr=="2005"))
ww[14,1]<-2006;ww[14,2]<-mean(subset(data$ww, data$yr=="2006")); ww[14,3]<-sd(subset(data$ww, data$yr=="2006")); ww[14,4]<-nrow(subset(data, yr=="2006"))
ww[15,1]<-2007;ww[15,2]<-mean(subset(data$ww, data$yr=="2007")); ww[15,3]<-sd(subset(data$ww, data$yr=="2007")); ww[15,4]<-nrow(subset(data, yr=="2007"))
ww[16,1]<-2008;ww[16,2]<-mean(subset(data$ww, data$yr=="2008")); ww[16,3]<-sd(subset(data$ww, data$yr=="2008")); ww[16,4]<-nrow(subset(data, yr=="2008"))
ww[17,1]<-2009;ww[17,2]<-mean(subset(data$ww, data$yr=="2009")); ww[17,3]<-sd(subset(data$ww, data$yr=="2009")); ww[17,4]<-nrow(subset(data, yr=="2009"))
ww[18,1]<-2010;ww[18,2]<-mean(subset(data$ww, data$yr=="2010")); ww[18,3]<-sd(subset(data$ww, data$yr=="2010")); ww[18,4]<-nrow(subset(data, yr=="2010"))
ww[19,1]<-2011;ww[19,2]<-mean(subset(data$ww, data$yr=="2011")); ww[19,3]<-sd(subset(data$ww, data$yr=="2011")); ww[19,4]<-nrow(subset(data, yr=="2011"))
ww[20,1]<-2012;ww[20,2]<-mean(subset(data$ww, data$yr=="2012")); ww[20,3]<-sd(subset(data$ww, data$yr=="2012")); ww[20,4]<-nrow(subset(data, yr=="2012"))

#WAB_small mean fork lengths

fl<-matrix(nrow=20, ncol=4)
colnames(fl)<-c("yr", "mean", "sd", "n")
fl[1,1]<-1993;fl[1,2]<-mean(subset(data$fl, data$yr=="1993")); fl[1,3]<-sd(subset(data$fl, data$yr=="1993")); fl[1,4]<-nrow(subset(data, yr=="1993"))
fl[2,1]<-1994;fl[2,2]<-mean(subset(data$fl, data$yr=="1994")); fl[2,3]<-sd(subset(data$fl, data$yr=="1994")); fl[2,4]<-nrow(subset(data, yr=="1994"))
fl[3,1]<-1995;fl[3,2]<-mean(subset(data$fl, data$yr=="1995")); fl[3,3]<-sd(subset(data$fl, data$yr=="1995")); fl[3,4]<-nrow(subset(data, yr=="1995"))
fl[4,1]<-1996;fl[4,2]<-mean(subset(data$fl, data$yr=="1996")); fl[4,3]<-sd(subset(data$fl, data$yr=="1996")); fl[4,4]<-nrow(subset(data, yr=="1996"))
fl[5,1]<-1997;fl[5,2]<-mean(subset(data$fl, data$yr=="1997")); fl[5,3]<-sd(subset(data$fl, data$yr=="1997")); fl[5,4]<-nrow(subset(data, yr=="1997"))
fl[6,1]<-1998;fl[6,2]<-mean(subset(data$fl, data$yr=="1998")); fl[6,3]<-sd(subset(data$fl, data$yr=="1998")); fl[6,4]<-nrow(subset(data, yr=="1998"))
fl[7,1]<-1999;fl[7,2]<-mean(subset(data$fl, data$yr=="1999")); fl[7,3]<-sd(subset(data$fl, data$yr=="1999")); fl[7,4]<-nrow(subset(data, yr=="1999"))
fl[8,1]<-2000;fl[8,2]<-mean(subset(data$fl, data$yr=="2000")); fl[8,3]<-sd(subset(data$fl, data$yr=="2000")); fl[8,4]<-nrow(subset(data, yr=="2000"))
fl[9,1]<-2001;fl[9,2]<-mean(subset(data$fl, data$yr=="2001")); fl[9,3]<-sd(subset(data$fl, data$yr=="2001")); fl[9,4]<-nrow(subset(data, yr=="2001"))
fl[10,1]<-2002;fl[10,2]<-mean(subset(data$fl, data$yr=="2002")); fl[10,3]<-sd(subset(data$fl, data$yr=="2002")); fl[10,4]<-nrow(subset(data, yr=="2002"))
fl[11,1]<-2003;fl[11,2]<-mean(subset(data$fl, data$yr=="2003")); fl[11,3]<-sd(subset(data$fl, data$yr=="2003")); fl[11,4]<-nrow(subset(data, yr=="2003"))
fl[12,1]<-2004;fl[12,2]<-mean(subset(data$fl, data$yr=="2004")); fl[12,3]<-sd(subset(data$fl, data$yr=="2004")); fl[12,4]<-nrow(subset(data, yr=="2004"))
fl[13,1]<-2005;fl[13,2]<-mean(subset(data$fl, data$yr=="2005")); fl[13,3]<-sd(subset(data$fl, data$yr=="2005")); fl[13,4]<-nrow(subset(data, yr=="2005"))
fl[14,1]<-2006;fl[14,2]<-mean(subset(data$fl, data$yr=="2006")); fl[14,3]<-sd(subset(data$fl, data$yr=="2006")); fl[14,4]<-nrow(subset(data, yr=="2006"))
fl[15,1]<-2007;fl[15,2]<-mean(subset(data$fl, data$yr=="2007")); fl[15,3]<-sd(subset(data$fl, data$yr=="2007")); fl[15,4]<-nrow(subset(data, yr=="2007"))
fl[16,1]<-2008;fl[16,2]<-mean(subset(data$fl, data$yr=="2008")); fl[16,3]<-sd(subset(data$fl, data$yr=="2008")); fl[16,4]<-nrow(subset(data, yr=="2008"))
fl[17,1]<-2009;fl[17,2]<-mean(subset(data$fl, data$yr=="2009")); fl[17,3]<-sd(subset(data$fl, data$yr=="2009")); fl[17,4]<-nrow(subset(data, yr=="2009"))
fl[18,1]<-2010;fl[18,2]<-mean(subset(data$fl, data$yr=="2010")); fl[18,3]<-sd(subset(data$fl, data$yr=="2010")); fl[18,4]<-nrow(subset(data, yr=="2010"))
fl[19,1]<-2011;fl[19,2]<-mean(subset(data$fl, data$yr=="2011")); fl[19,3]<-sd(subset(data$fl, data$yr=="2011")); fl[19,4]<-nrow(subset(data, yr=="2011"))
fl[20,1]<-2012;fl[20,2]<-mean(subset(data$fl, data$yr=="2012")); fl[20,3]<-sd(subset(data$fl, data$yr=="2012")); fl[20,4]<-nrow(subset(data, yr=="2012"))

wab.s.fl<-fl
rm(fl)

wab.s.ww<-ww
rm(ww)

rm(data)
####WESTERN ARM LARGE SALMON
data<-wab.l

ww<-matrix(nrow=20, ncol=4)
colnames(ww)<-c("yr", "mean", "sd", "n")

ww[1,1]<-1993;ww[1,2]<-mean(subset(data$ww, data$yr=="1993")); ww[1,3]<-sd(subset(data$ww, data$yr=="1993")); ww[1,4]<-nrow(subset(data, yr=="1993"))
ww[2,1]<-1994;ww[2,2]<-mean(subset(data$ww, data$yr=="1994")); ww[2,3]<-sd(subset(data$ww, data$yr=="1994")); ww[2,4]<-nrow(subset(data, yr=="1994"))
ww[3,1]<-1995;ww[3,2]<-mean(subset(data$ww, data$yr=="1995")); ww[3,3]<-sd(subset(data$ww, data$yr=="1995")); ww[3,4]<-nrow(subset(data, yr=="1995"))
ww[4,1]<-1996;ww[4,2]<-mean(subset(data$ww, data$yr=="1996")); ww[4,3]<-sd(subset(data$ww, data$yr=="1996")); ww[4,4]<-nrow(subset(data, yr=="1996"))
ww[5,1]<-1997;ww[5,2]<-mean(subset(data$ww, data$yr=="1997")); ww[5,3]<-sd(subset(data$ww, data$yr=="1997")); ww[5,4]<-nrow(subset(data, yr=="1997"))
ww[6,1]<-1998;ww[6,2]<-mean(subset(data$ww, data$yr=="1998")); ww[6,3]<-sd(subset(data$ww, data$yr=="1998")); ww[6,4]<-nrow(subset(data, yr=="1998"))
ww[7,1]<-1999;ww[7,2]<-mean(subset(data$ww, data$yr=="1999")); ww[7,3]<-sd(subset(data$ww, data$yr=="1999")); ww[7,4]<-nrow(subset(data, yr=="1999"))
ww[8,1]<-2000;ww[8,2]<-mean(subset(data$ww, data$yr=="2000")); ww[8,3]<-sd(subset(data$ww, data$yr=="2000")); ww[8,4]<-nrow(subset(data, yr=="2000"))
ww[9,1]<-2001;ww[9,2]<-mean(subset(data$ww, data$yr=="2001")); ww[9,3]<-sd(subset(data$ww, data$yr=="2001")); ww[9,4]<-nrow(subset(data, yr=="2001"))
ww[10,1]<-2002;ww[10,2]<-mean(subset(data$ww, data$yr=="2002")); ww[10,3]<-sd(subset(data$ww, data$yr=="2002")); ww[10,4]<-nrow(subset(data, yr=="2002"))
ww[11,1]<-2003;ww[11,2]<-mean(subset(data$ww, data$yr=="2003")); ww[11,3]<-sd(subset(data$ww, data$yr=="2003")); ww[11,4]<-nrow(subset(data, yr=="2003"))
ww[12,1]<-2004;ww[12,2]<-mean(subset(data$ww, data$yr=="2004")); ww[12,3]<-sd(subset(data$ww, data$yr=="2004")); ww[12,4]<-nrow(subset(data, yr=="2004"))
ww[13,1]<-2005;ww[13,2]<-mean(subset(data$ww, data$yr=="2005")); ww[13,3]<-sd(subset(data$ww, data$yr=="2005")); ww[13,4]<-nrow(subset(data, yr=="2005"))
ww[14,1]<-2006;ww[14,2]<-mean(subset(data$ww, data$yr=="2006")); ww[14,3]<-sd(subset(data$ww, data$yr=="2006")); ww[14,4]<-nrow(subset(data, yr=="2006"))
ww[15,1]<-2007;ww[15,2]<-mean(subset(data$ww, data$yr=="2007")); ww[15,3]<-sd(subset(data$ww, data$yr=="2007")); ww[15,4]<-nrow(subset(data, yr=="2007"))
ww[16,1]<-2008;ww[16,2]<-mean(subset(data$ww, data$yr=="2008")); ww[16,3]<-sd(subset(data$ww, data$yr=="2008")); ww[16,4]<-nrow(subset(data, yr=="2008"))
ww[17,1]<-2009;ww[17,2]<-mean(subset(data$ww, data$yr=="2009")); ww[17,3]<-sd(subset(data$ww, data$yr=="2009")); ww[17,4]<-nrow(subset(data, yr=="2009"))
ww[18,1]<-2010;ww[18,2]<-mean(subset(data$ww, data$yr=="2010")); ww[18,3]<-sd(subset(data$ww, data$yr=="2010")); ww[18,4]<-nrow(subset(data, yr=="2010"))
ww[19,1]<-2011;ww[19,2]<-mean(subset(data$ww, data$yr=="2011")); ww[19,3]<-sd(subset(data$ww, data$yr=="2011")); ww[19,4]<-nrow(subset(data, yr=="2011"))
ww[20,1]<-2012;ww[20,2]<-mean(subset(data$ww, data$yr=="2012")); ww[20,3]<-sd(subset(data$ww, data$yr=="2012")); ww[20,4]<-nrow(subset(data, yr=="2012"))

#WAB_large mean fork lengths

fl<-matrix(nrow=20, ncol=4)
colnames(fl)<-c("yr", "mean", "sd", "n")
fl[1,1]<-1993;fl[1,2]<-mean(subset(data$fl, data$yr=="1993")); fl[1,3]<-sd(subset(data$fl, data$yr=="1993")); fl[1,4]<-nrow(subset(data, yr=="1993"))
fl[2,1]<-1994;fl[2,2]<-mean(subset(data$fl, data$yr=="1994")); fl[2,3]<-sd(subset(data$fl, data$yr=="1994")); fl[2,4]<-nrow(subset(data, yr=="1994"))
fl[3,1]<-1995;fl[3,2]<-mean(subset(data$fl, data$yr=="1995")); fl[3,3]<-sd(subset(data$fl, data$yr=="1995")); fl[3,4]<-nrow(subset(data, yr=="1995"))
fl[4,1]<-1996;fl[4,2]<-mean(subset(data$fl, data$yr=="1996")); fl[4,3]<-sd(subset(data$fl, data$yr=="1996")); fl[4,4]<-nrow(subset(data, yr=="1996"))
fl[5,1]<-1997;fl[5,2]<-mean(subset(data$fl, data$yr=="1997")); fl[5,3]<-sd(subset(data$fl, data$yr=="1997")); fl[5,4]<-nrow(subset(data, yr=="1997"))
fl[6,1]<-1998;fl[6,2]<-mean(subset(data$fl, data$yr=="1998")); fl[6,3]<-sd(subset(data$fl, data$yr=="1998")); fl[6,4]<-nrow(subset(data, yr=="1998"))
fl[7,1]<-1999;fl[7,2]<-mean(subset(data$fl, data$yr=="1999")); fl[7,3]<-sd(subset(data$fl, data$yr=="1999")); fl[7,4]<-nrow(subset(data, yr=="1999"))
fl[8,1]<-2000;fl[8,2]<-mean(subset(data$fl, data$yr=="2000")); fl[8,3]<-sd(subset(data$fl, data$yr=="2000")); fl[8,4]<-nrow(subset(data, yr=="2000"))
fl[9,1]<-2001;fl[9,2]<-mean(subset(data$fl, data$yr=="2001")); fl[9,3]<-sd(subset(data$fl, data$yr=="2001")); fl[9,4]<-nrow(subset(data, yr=="2001"))
fl[10,1]<-2002;fl[10,2]<-mean(subset(data$fl, data$yr=="2002")); fl[10,3]<-sd(subset(data$fl, data$yr=="2002")); fl[10,4]<-nrow(subset(data, yr=="2002"))
fl[11,1]<-2003;fl[11,2]<-mean(subset(data$fl, data$yr=="2003")); fl[11,3]<-sd(subset(data$fl, data$yr=="2003")); fl[11,4]<-nrow(subset(data, yr=="2003"))
fl[12,1]<-2004;fl[12,2]<-mean(subset(data$fl, data$yr=="2004")); fl[12,3]<-sd(subset(data$fl, data$yr=="2004")); fl[12,4]<-nrow(subset(data, yr=="2004"))
fl[13,1]<-2005;fl[13,2]<-mean(subset(data$fl, data$yr=="2005")); fl[13,3]<-sd(subset(data$fl, data$yr=="2005")); fl[13,4]<-nrow(subset(data, yr=="2005"))
fl[14,1]<-2006;fl[14,2]<-mean(subset(data$fl, data$yr=="2006")); fl[14,3]<-sd(subset(data$fl, data$yr=="2006")); fl[14,4]<-nrow(subset(data, yr=="2006"))
fl[15,1]<-2007;fl[15,2]<-mean(subset(data$fl, data$yr=="2007")); fl[15,3]<-sd(subset(data$fl, data$yr=="2007")); fl[15,4]<-nrow(subset(data, yr=="2007"))
fl[16,1]<-2008;fl[16,2]<-mean(subset(data$fl, data$yr=="2008")); fl[16,3]<-sd(subset(data$fl, data$yr=="2008")); fl[16,4]<-nrow(subset(data, yr=="2008"))
fl[17,1]<-2009;fl[17,2]<-mean(subset(data$fl, data$yr=="2009")); fl[17,3]<-sd(subset(data$fl, data$yr=="2009")); fl[17,4]<-nrow(subset(data, yr=="2009"))
fl[18,1]<-2010;fl[18,2]<-mean(subset(data$fl, data$yr=="2010")); fl[18,3]<-sd(subset(data$fl, data$yr=="2010")); fl[18,4]<-nrow(subset(data, yr=="2010"))
fl[19,1]<-2011;fl[19,2]<-mean(subset(data$fl, data$yr=="2011")); fl[19,3]<-sd(subset(data$fl, data$yr=="2011")); fl[19,4]<-nrow(subset(data, yr=="2011"))
fl[20,1]<-2012;fl[20,2]<-mean(subset(data$fl, data$yr=="2012")); fl[20,3]<-sd(subset(data$fl, data$yr=="2012")); fl[20,4]<-nrow(subset(data, yr=="2012"))

wab.l.fl<-fl
rm(fl)

wab.l.ww<-ww
rm(ww)

rm(data)

#Transform all matrices to data frames so that they can be easily imported into p.flux.master code
cam.s.ww<-as.data.frame(cam.s.ww)
cam.l.ww<-as.data.frame(cam.l.ww)
cam.s.fl<-as.data.frame(cam.s.fl)
cam.l.fl<-as.data.frame(cam.l.fl)

cn.s.ww<-as.data.frame(cn.s.ww)
cn.l.ww<-as.data.frame(cn.l.ww)
cn.s.fl<-as.data.frame(cn.s.fl)
cn.l.fl<-as.data.frame(cn.l.fl)

wab.s.ww<-as.data.frame(wab.s.ww)
wab.l.ww<-as.data.frame(wab.l.ww)
wab.s.fl<-as.data.frame(wab.s.fl)
wab.l.fl<-as.data.frame(wab.l.fl)

### Rearrange dataframes so that they are able to be merged with "salmon dataset" in p.flux.master.R
#Add strm to all existing data frames so that it makes life easier 
cam.s.ww$strm<-rep("cam", length(cam.s.ww$yr))
cn.s.ww$strm<-rep("cn", length(cn.s.ww$yr))
wab.s.ww$strm<-rep("wab", length(wab.s.ww$yr))

cam.weight<-data.frame(strm=cam.s.ww$strm, yr=cam.s.ww$yr, ww.s=cam.s.ww$mean, fl.s=cam.s.fl$mean)
cam.weight$ww.l<-cam.l.ww$mean
cam.weight$fl.l<-cam.l.fl$mean


cn.weight<-data.frame(strm=cn.s.ww$strm, yr=cn.s.ww$yr, ww.s=cn.s.ww$mean, fl.s=cn.s.fl$mean)
cn.weight$ww.l<-cn.l.ww$mean
cn.weight$fl.l<-cn.l.fl$mean

wab.weight<-data.frame(strm=wab.s.ww$strm, yr=wab.s.ww$yr, ww.s=wab.s.ww$mean, fl.s=wab.s.fl$mean)
wab.weight$ww.l<-wab.l.ww$mean
wab.weight$fl.l<-wab.l.fl$mean

weight<-rbind(cam.weight, cn.weight, wab.weight)

#because there is no large fish data for Conne for the period 1993-2012, I use data from six fish recorded between 1986 and 1992.

cn.large.ww<-c(3.5, 3.2, 2.7, 2.7, 2.6)#measurements of Conne large salmon weights from 1989, 1989, 1989, 1992, 1986, respectively.
cn.large.fl<-c(70, 66, 65, 65, 63)#measurements of Conne large salmon weights from 1989, 1989, 1989, 1992, 1986, respectively.

sd(cn.large.ww)
sd(cn.large.fl)

##
# mean weights of all adults. This information is included in Appendix A of Ebel et al. [submitted]
mass<-matrix(nrow=6, ncol=8)
colnames(mass)<-c("strm", "ls", "mean WW", "sd","n", "mean fl", "sd", "n")

mass[1,1]<-"Campbellton"; mass[1,2]<-"small"; mass[1,3]<-mean(cam.s$ww); mass[1,4]<-sd(cam.s$ww); mass[1,5]<-nrow(cam.s); mass[1,6]<-mean(cam.s$fl); mass[1,7]<-sd(cam.s$fl); mass[1,8]<-nrow(cam.s)
mass[2,1]<-""; mass[2,2]<-"large"; mass[2,3]<-mean(cam.l$ww); mass[2,4]<-sd(cam.l$ww); mass[2,5]<-nrow(cam.l); mass[2,6]<-mean(cam.l$fl); mass[2,7]<-sd(cam.l$fl); mass[2,8]<-nrow(cam.l)
mass[3,1]<-"Conne"; mass[3,2]<-"small";mass[3,3]<-mean(cn.s$ww); mass[3,4]<-sd(cn.s$ww); mass[3,5]<-nrow(cn.s); mass[3,6]<-mean(cn.s$fl); mass[3,7]<-sd(cn.s$fl); mass[3,8]<-nrow(cn.s)
mass[4,1]<-""; mass[4,2]<-"large"; mass[4,3]<-mean(cn.l$ww); mass[4,4]<-sd(cn.l$ww); mass[4,5]<-nrow(cn.l); mass[4,6]<-mean(cn.l$fl); mass[4,7]<-sd(cn.l$fl); mass[4,8]<-nrow(cn.l)
mass[5,1]<-"Western Arm"; mass[5,2]<-"small"; mass[5,3]<-mean(wab.s$ww); mass[5,4]<-sd(wab.s$ww); mass[5,5]<-nrow(wab.s); mass[5,6]<-mean(wab.s$fl); mass[5,7]<-sd(wab.s$fl); mass[5,8]<-nrow(wab.s)
mass[6,1]<-""; mass[6,2]<-"large"; mass[6,3]<-mean(wab.l$ww); mass[6,4]<-sd(wab.l$ww); mass[6,5]<-nrow(wab.l); mass[6,6]<-mean(wab.l$fl); mass[6,7]<-sd(wab.l$fl); mass[6,8]<-nrow(wab.l)

#################################################################################################################################################


########Length-Weight regressions used to calculate parameter b in nutrient flux model. 

#The code uses 2014 adult and kelt length weight data from original data file "FL and WW data for CN CMP and WAB" sent by Martha Robertson on 14Nov2014.
#Kelt data includes fish from Campbellton and Western Arm only, whereas adult data is from all three study rivers.
#Rivers were not used to make separate calculations of parameter b because of the lack of Conne kelt data.

#Code Summary
#This code seeks to calculate parameter b in a nutrient transport model for Atlantic salmon.


#Figshare datafile names adult.lw.csv and kelt.lw.csv

# subset data to examine for differences between rivers
k.cam<-subset(kelt.lw, strm=="CAM")
k.wab<-subset(kelt.lw, strm=="WAB")
a.cam<-subset(adult.lw, strm=="CAM")
a.cn<-subset(adult.lw, strm=="CN")
a.wab<-subset(adult.lw, strm=="WAB")

#check adult and kelt plots
plot(log10(kelt.lw$fl),log10(kelt.lw$wt), ylim=c(2,5), xlim=c(1,5))
points(log10(adult.lw$fl), log10(adult.lw$wt), pch=4)

#Get coefficients and intercept for length-weight regression for river specific b
k.regression<-summary(lm(log10(kelt.lw$wt)~log10(kelt.lw$fl)))
a.regression<-summary(lm(log10(adult.lw$wt)~log10(adult.lw$fl)))

k.regression$coefficients[1]

#make figure of length-weight regression

fxn<-NULL
L<-seq(0,900,10)
fxn<-data.frame(L=L)
b<-((10^(k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(L))))/ 10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(L))))
fxn<-cbind(fxn, data.frame(b))

mass.loss<-fxn
rm(fxn)

k.lw<-10^(k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(L)))
a.lw<-10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(L)))

#########################################################################################################
#FIGURE 3 IN EBEL, LEROUX, ROBERTSON, DEMPSON

x11(height=4, width=6.5)
par(mfrow=c(1,2))
par(oma=c(1,1,1,1)) #sets outer margins
par(mar=c(2,2,1,2))
par(las=1)
par(mgp=c(1, 1, 0))

plot(adult.lw$wt~adult.lw$fl, xlim=c(0,900),cex=0.5, ylim=c(0,7000), pch=2, ylab="", xlab="")
points(kelt.lw$wt~kelt.lw$fl, pch=1, cex=0.5, xlab="", ylab="")
points(k.lw~L, type="l")
points(a.lw~L, type="l")
legend("topleft", legend=c("Adult", "Kelt"), pch=c(2, 1), pt.cex=2, bty="n")

plot(mass.loss$b~mass.loss$L, type="l", xlab="", ylab="", ylim=c(0,1), yaxt="n", lwd=2)
axis(4, seq(0,1,0.2))
####################################################################################################################################################

#THIS SECTION OF CODE CALCULATES P FLUX USING PARAMETERS ESTIMATED IN CODE SECTIONS ABOVE. IT PRODUCES LARGE DATAFRAMES OF ALL PARAMETERS AND RESULTS FOR EACH STREAM


#Figshare datafile name: salmon.count.csv

kelt.survival<-c(0.7429, 0.7674, 0.7262, 0.7499, 0.5684, 0.5281, 0.4558, 0.5735, 0.4650, 0.3475, 0.5801, 
                 0.5320, 0.7110, 0.4833, 0.3109, 0.6416, 0.4453) # M Robertson unpublished data

mean(kelt.survival)

#Break Master salmon count data frame into subsets by stream
data<-salmon
data$AMS<-weight$ww.s
data$AML<-weight$ww.l
data$ALS<-weight$fl.s
data$ALL<-weight$fl.l

CAM<-subset(data, STRM=="CAM")
CN<-subset(data, STRM=="CN")
WAB<-subset(data, STRM=="WAB")

#Replace missing weight values with mean values
CAM$ams<-ifelse(is.nan(CAM$AMS), mean(CAM$AMS, na.rm=TRUE), CAM$AMS)
CAM$aml<-ifelse(is.nan(CAM$AML), mean(CAM$AML, na.rm=TRUE), CAM$AML)
CAM$als<-ifelse(is.nan(CAM$ALS), mean(CAM$ALS, na.rm=TRUE), CAM$ALS)
CAM$all<-ifelse(is.nan(CAM$ALL), mean(CAM$ALL, na.rm=TRUE), CAM$ALL)
CAM$sm<-ifelse(CAM$S_M==-1, mean(CAM$S_MASS, na.rm=TRUE), CAM$S_M)

CN$ams<-ifelse(is.nan(CN$AMS), mean(CN$AMS, na.rm=TRUE), CN$AMS)
CN$aml<-ifelse(is.nan(CN$AML), mean(cn.large.ww, na.rm=TRUE), CN$AML)#uses values from 6 fish. cn.large.ww is found in p.flux.adult.weights.R
CN$als<-ifelse(is.nan(CN$ALS), mean(CN$ALS, na.rm=TRUE), CN$ALS)
CN$all<-ifelse(is.nan(CN$ALL), mean(cn.large.fl, na.rm=TRUE), CN$ALL)#uses values from 6 fish. cn.large.fl is found in p.flux.adult.weights.R
CN$sm<-ifelse(CN$S_M==-1, mean(CN$S_MASS, na.rm=TRUE), CN$S_M)

WAB$ams<-ifelse(is.nan(WAB$AMS), mean(WAB$AMS, na.rm=TRUE), WAB$AMS)
WAB$aml<-ifelse(is.nan(WAB$AML), mean(WAB$AML, na.rm=TRUE), WAB$AML)
WAB$als<-ifelse(is.nan(WAB$ALS), mean(WAB$ALS, na.rm=TRUE), WAB$ALS)
WAB$all<-ifelse(is.nan(WAB$ALL), mean(WAB$ALL, na.rm=TRUE), WAB$ALL)
WAB$sm<-ifelse(WAB$S_M==-1, mean(WAB$S_MASS, na.rm=TRUE), WAB$S_M)

rm(data)
###################################################################################################
#Campbellton 
#Changed from large.fish.contribution.R to separate counts and # spawners (as provided by DFO). # small spawners = sp.sm, # large spawners = sp.lg
data<-CAM

CAM_PARAMETERS<-data.frame(strm=data$STRM, yr=data$YR, 
                           acs=data$A_COUNT_SM, acl=data$A_COUNT_LG, #Adult counts 
                           sp.sm=data$A_SPAWNER_SM, sp.lg=data$A_SPAWNER_LG,#Spawner counts
                           sc=data$S_COUNT, #smolt count 
                           ams=data$ams, aml=data$aml, sm=data$sm,#adult and smolt mass data
                           als=data$als, all=data$all, # adult lengths
                           #Stream and life stage specific P contents
                           anut=(rep((rls.means[1,1]/100),length(data$YR))), #adult nutrient concentration
                           knut=(rep((rls.means[1,3]/100),length(data$YR))), #kelt nutrient concentration
                           snut=(rep((rls.means[1,5]/100),length(data$YR))), #smolt nutrient concentration
                           #Newfoundland salmon P content pooled
                           nl.anut=(rep((ls.means[1,1]/100),length(data$YR))), 
                           nl.knut=(rep((ls.means[2,1]/100),length(data$YR))), 
                           nl.snut=(rep((ls.means[3,1]/100),length(data$YR))),
                           #Lyle and Elliot Numbers
                           le.anut=(rep((0.47/100),length(data$YR))), 
                           le.knut=(rep((0.47/100), length(data$YR))), 
                           le.snut=(rep((0.45/100), length(data$YR))),
                           #Post spawn survival and mass loss
                           ksurv = rep(mean(kelt.survival),length(data$YR)), 
                           kmp.s=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als*10))))),
                           kmp.l=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$all*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$all*10)))))
)
rm(data)

#Calculate Import, Export, Flux using 2013 river specific P-content, pooled from three NL rivers, and values from Lyle and Elliot(1998)

data<-CAM_PARAMETERS

data$t=c(1:length(data$yr))
data$ac.sum=c(sapply(1:length(data$yr), function(x)"+"(data$acs[x], data$acl[x]))) #Total number of adults passing through counting fence
data$sp.sum=c(sapply(1:length(data$yr), function(x)"+"(data$sp.sm[x], data$sp.lg[x]))) #Number of adults spawning (Count - known recreational angler harvests)

#flux using river-specific measurements

data$import.c.sm=(data$acs*data$ams*data$anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$import.c.lg= (data$acl*data$aml*data$anut) #Maximum potential import by large adults (uses COUNTS)

data$import.sp.sm = (data$sp.sm*data$ams*data$anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$import.sp.lg = (data$sp.lg*data$aml*data$anut) #Actual import after accounting for recreational angling harvest of large salmon

data$exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$knut)

data$netimport.sm = data$import.sp.sm-data$exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$netimport.lg=data$import.sp.lg-data$exportk.lg

data$exports = data$sc * data$sm*data$snut #Calculates Export by smolt

data$f=(data$netimport.sm + data$netimport.lg) - data$exports #Calculates nutrient flux

#flux using regional estimates (ls stands for life stage)
data$nl.import.c.sm=(data$acs*data$ams*data$nl.anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$nl.import.c.lg= (data$acl*data$aml*data$nl.anut) #Maximum potential import by large adults (uses COUNTS)
data$nl.import.sp.sm = (data$sp.sm*data$ams*data$nl.anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$nl.import.sp.lg = (data$sp.lg*data$aml*data$nl.anut) #Actual import after accounting for recreational angling harvest of large salmon
data$nl.exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$nl.knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$nl.exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$nl.knut)
data$nl.netimport.sm = data$nl.import.sp.sm-data$nl.exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$nl.netimport.lg=data$nl.import.sp.lg-data$nl.exportk.lg
data$nl.exports = data$sc * data$sm*data$nl.snut #Calculates Export by smolts
data$nl.f=(data$nl.netimport.sm + data$nl.netimport.lg) - data$nl.exports #Calculates nutrient flux

#flux using Lyle and Elliot values
data$le.import.c.sm=(data$acs*data$ams*data$le.anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$le.import.c.lg= (data$acl*data$aml*data$le.anut) #Maximum potential import by large adults (uses COUNTS)
data$le.import.sp.sm = (data$sp.sm*data$ams*data$le.anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$le.import.sp.lg = (data$sp.lg*data$aml*data$le.anut) #Actual import after accounting for recreational angling harvest of large salmon
data$le.exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$le.knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$le.exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$le.knut)
data$le.netimport.sm = data$le.import.sp.sm-data$le.exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$le.netimport.lg=data$le.import.sp.lg-data$le.exportk.lg
data$le.exports = data$sc * data$sm*data$le.snut #Calculates Export by smolt
data$le.f=(data$le.netimport.sm + data$le.netimport.lg) - data$le.exports #Calculates nutrient flux

CAM_MASTER<-data
CAM_MASTER
rm(data)

################################################################################################
#Calculates P flux to CONNE RIVER
data<-CN

CN_PARAMETERS<-data.frame(strm=data$STRM, yr=data$YR, 
                          acs=data$A_COUNT_SM, acl=data$A_COUNT_LG, #Adult counts 
                          sp.sm=data$A_SPAWNER_SM, sp.lg=data$A_SPAWNER_LG,#Spawner counts
                          sc=data$S_COUNT, #smolt count 
                          ams=data$ams, aml=data$aml, sm=data$sm,#adult and smolt mass data
                          als=data$als, all=data$all, # adult lengths
                          #Stream and life stage specific P contents
                          anut=(rep((rls.means[2,1]/100),length(data$YR))), #adult nutrient concentration
                          knut=(rep((rls.means[2,3]/100),length(data$YR))), #kelt nutrient concentration
                          snut=(rep((rls.means[2,5]/100),length(data$YR))), #smolt nutrient concentration
                          #Newfoundland salmon P content pooled
                          nl.anut=(rep((ls.means[1,1]/100),length(data$YR))), 
                          nl.knut=(rep((ls.means[2,1]/100),length(data$YR))), 
                          nl.snut=(rep((ls.means[3,1]/100),length(data$YR))),
                          #Lyle and Elliot Numbers
                          le.anut=(rep((0.47/100),length(data$YR))), 
                          le.knut=(rep((0.47/100), length(data$YR))), 
                          le.snut=(rep((0.45/100), length(data$YR))),
                          #Post spawn survival and mass loss
                          ksurv = rep(mean(kelt.survival),length(data$YR)), 
                          kmp.s=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als*10))))), #Parameter b code uses mm, whereas data$als is in cm. therefore I multiply $als by 10.
                          kmp.l=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$all*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$all*10)))))
)
rm(data)

#Calculate Import, Export, Flux using 2013 river specific P-content, pooled from three NL rivers, and values from Lyle and Elliot(1998)
data<-CN_PARAMETERS

data$t=c(1:length(data$yr))
data$ac.sum=c(sapply(1:length(data$yr), function(x)"+"(data$acs[x], data$acl[x]))) #Total number of adults passing through counting fence
data$sp.sum=c(sapply(1:length(data$yr), function(x)"+"(data$sp.sm[x], data$sp.lg[x]))) #Number of adults spawning (Count - known recreational angler harvests)

#flux using river-specific measurements
data$import.c.sm=(data$acs*data$ams*data$anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$import.c.lg= (data$acl*data$aml*data$anut) #Maximum potential import by large adults (uses COUNTS)

data$import.sp.sm = (data$sp.sm*data$ams*data$anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$import.sp.lg = (data$sp.lg*data$aml*data$anut) #Actual import after accounting for recreational angling harvest of large salmon

data$exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$knut)

data$netimport.sm = data$import.sp.sm-data$exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$netimport.lg=data$import.sp.lg-data$exportk.lg

data$exports = data$sc * data$sm*data$snut #Calculates Export by smolt

data$f=(data$netimport.sm + data$netimport.lg) - data$exports #Calculates nutrient flux

#flux using regional estimates (ls stands for life stage)
data$nl.import.c.sm=(data$acs*data$ams*data$nl.anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$nl.import.c.lg= (data$acl*data$aml*data$nl.anut) #Maximum potential import by large adults (uses COUNTS)
data$nl.import.sp.sm = (data$sp.sm*data$ams*data$nl.anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$nl.import.sp.lg = (data$sp.lg*data$aml*data$nl.anut) #Actual import after accounting for recreational angling harvest of large salmon
data$nl.exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$nl.knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$nl.exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$nl.knut)
data$nl.netimport.sm = data$nl.import.sp.sm-data$nl.exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$nl.netimport.lg=data$nl.import.sp.lg-data$nl.exportk.lg
data$nl.exports = data$sc * data$sm*data$nl.snut #Calculates Export by smolt
data$nl.f=(data$nl.netimport.sm + data$nl.netimport.lg) - data$nl.exports #Calculates nutrient flux


#flux using Lyle and Elliot values
data$le.import.c.sm=(data$acs*data$ams*data$le.anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$le.import.c.lg= (data$acl*data$aml*data$le.anut) #Maximum potential import by large adults (uses COUNTS)
data$le.import.sp.sm = (data$sp.sm*data$ams*data$le.anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$le.import.sp.lg = (data$sp.lg*data$aml*data$le.anut) #Actual import after accounting for recreational angling harvest of large salmon
data$le.exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$le.knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$le.exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$le.knut)
data$le.netimport.sm = data$le.import.sp.sm-data$le.exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$le.netimport.lg=data$le.import.sp.lg-data$le.exportk.lg
data$le.exports = data$sc * data$sm*data$le.snut #Calculates Export by smolt

data$le.f=(data$le.netimport.sm + data$le.netimport.lg) - data$le.exports #Calculates nutrient flux

CN_MASTER<-data
CN_MASTER
rm(data)

################################################################################################
#Calculates P flux to WESTERN ARM BROOK
data<-WAB

WAB_PARAMETERS<-data.frame(strm=data$STRM, yr=data$YR, 
                           acs=data$A_COUNT_SM, acl=data$A_COUNT_LG, #Adult counts 
                           sp.sm=data$A_SPAWNER_SM, sp.lg=data$A_SPAWNER_LG,#Spawner counts
                           sc=data$S_COUNT, #smolt count 
                           ams=data$ams, aml=data$aml, sm=data$sm,#adult and smolt mass data
                           als=data$als, all=data$all, # adult lengths
                           #Stream and life stage specific P contents
                           anut=(rep((rls.means[3,1]/100),length(data$YR))), #adult nutrient concentration
                           knut=(rep((rls.means[3,3]/100),length(data$YR))), #kelt nutrient concentration
                           snut=(rep((rls.means[3,5]/100),length(data$YR))), #smolt nutrient concentration
                           #Newfoundland salmon P content pooled
                           nl.anut=(rep((ls.means[1,1]/100),length(data$YR))), 
                           nl.knut=(rep((ls.means[2,1]/100),length(data$YR))), 
                           nl.snut=(rep((ls.means[3,1]/100),length(data$YR))),
                           #Lyle and Elliot Numbers
                           le.anut=(rep((0.47/100),length(data$YR))), 
                           le.knut=(rep((0.47/100), length(data$YR))), 
                           le.snut=(rep((0.45/100), length(data$YR))),
                           #Post spawn survival and mass loss
                           ksurv = rep(mean(kelt.survival),length(data$YR)), 
                           kmp.s=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als*10))))),
                           kmp.l=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$all*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$all*10)))))
)
rm(data)

kmp.test<-((10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als))))-(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als))))))/(10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als))))

#Calculate Import, Export, Flux using 2013 river specific P-content, pooled from three NL rivers, and values from Lyle and Elliot(1998)
data<-WAB_PARAMETERS
data$t=c(1:length(data$yr))
data$ac.sum=c(sapply(1:length(data$yr), function(x)"+"(data$acs[x], data$acl[x]))) #Total number of adults passing through counting fence
data$sp.sum=c(sapply(1:length(data$yr), function(x)"+"(data$sp.sm[x], data$sp.lg[x]))) #Number of adults spawning (Count - known recreational angler harvests)

#flux using river-specific measurements

data$import.c.sm=(data$acs*data$ams*data$anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$import.c.lg= (data$acl*data$aml*data$anut) #Maximum potential import by large adults (uses COUNTS)

data$import.sp.sm = (data$sp.sm*data$ams*data$anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$import.sp.lg = (data$sp.lg*data$aml*data$anut) #Actual import after accounting for recreational angling harvest of large salmon

data$exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$knut)

data$netimport.sm = data$import.sp.sm-data$exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$netimport.lg=data$import.sp.lg-data$exportk.lg

data$exports = data$sc * data$sm*data$snut #Calculates Export by smolt

data$f=(data$netimport.sm + data$netimport.lg) - data$exports #Calculates nutrient flux

#flux using regional estimates (ls stands for life stage)
data$nl.import.c.sm=(data$acs*data$ams*data$nl.anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$nl.import.c.lg= (data$acl*data$aml*data$nl.anut) #Maximum potential import by large adults (uses COUNTS)
data$nl.import.sp.sm = (data$sp.sm*data$ams*data$nl.anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$nl.import.sp.lg = (data$sp.lg*data$aml*data$nl.anut) #Actual import after accounting for recreational angling harvest of large salmon
data$nl.exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$nl.knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$nl.exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$nl.knut)
data$nl.netimport.sm = data$nl.import.sp.sm-data$nl.exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$nl.netimport.lg=data$nl.import.sp.lg-data$nl.exportk.lg
data$nl.exports = data$sc * data$sm*data$nl.snut #Calculates Export by smolt
data$nl.f=(data$nl.netimport.sm + data$nl.netimport.lg) - data$nl.exports #Calculates nutrient flux


#flux using Lyle and Elliot values
data$le.import.c.sm=(data$acs*data$ams*data$le.anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$le.import.c.lg= (data$acl*data$aml*data$le.anut) #Maximum potential import by large adults (uses COUNTS)
data$le.import.sp.sm = (data$sp.sm*data$ams*data$le.anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$le.import.sp.lg = (data$sp.lg*data$aml*data$le.anut) #Actual import after accounting for recreational angling harvest of large salmon
data$le.exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$le.knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$le.exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$le.knut)
data$le.netimport.sm = data$le.import.sp.sm-data$le.exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$le.netimport.lg=data$le.import.sp.lg-data$le.exportk.lg
data$le.exports = data$sc * data$sm*data$le.snut #Calculates Export by smolt
data$le.f=(data$le.netimport.sm + data$le.netimport.lg) - data$le.exports #Calculates nutrient flux

WAB_MASTER<-data
WAB_MASTER
rm(data)

###############################################################################################################################################################

#Comparing the flux time series calculated using river-specific, province-wide, and Lyle and Elliot P concentration values
#USES A BRUTE FORCE REGRESSION coded directly from a textbook. 

###################################################################

#Campbellton
data<-CAM_MASTER
lm_1<-summary(lm(data$f~data$t)) #population specific
lm_2<-summary(lm(data$nl.f~data$t)) #pooled p-content
lm_3<-summary(lm(data$le.f~data$t)) #Lyle and Elliot

plot(data$f~data$t, type="l", ylim=c(-20, 20), lwd=2)
lines(data$nl.f~data$t, type="l", lty="dashed")
lines(data$le.f~data$t, type="l", lwd=1.5)
abline(lm_1)
abline(lm_2)
abline(lm_3)

#Comparing the slopes and elevations of the three regressions See Zar 5th Edition section 18.4 p.373

slope<-matrix(nrow=6, ncol=8)
rownames(slope)<-c("lm_1", "lm_2", "lm_3", "pooled_reg", "common_reg", "total_reg")
colnames(slope)<-c("sigma_x^2", "sigma_xy", "sigma_y^2", "residual_ss","n", "residual_df", "b", "residual mean square (s^2)")

#Sigma x^2 (sum of squares)
slope[1,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t)) 
slope[2,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[3,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[5,1]<-slope[1,1]+slope[2,1]+slope[3,1]
slope[6,1]<-(sum(data$t^2)*3)-(((sum(data$t)^2)*3)/(length(data$t)*3))

slope[1,5]<-length(data$t) #sample size (n)
slope[2,5]<-length(data$t)
slope[3,5]<-length(data$t)
slope[6,5]<-length(data$t)*3

#Sigma xy or "sum of cross products"
slope[1,2]<-sum(data$f*data$t)-((sum(data$f)*sum(data$t))/length(data$t)) 
slope[2,2]<-sum(data$nl.f*data$t)-((sum(data$nl.f)*sum(data$t))/length(data$t)) 
slope[3,2]<-sum(data$le.f*data$t)-((sum(data$le.f)*sum(data$t))/length(data$t)) 
slope[5,2]<-slope[1,2]+slope[2,2]+slope[3,2]
slope[6,2]<-(sum(data$f*data$t)+sum(data$nl.f*data$t)+sum(data$le.f*data$t))-(((sum(data$f)+sum(data$nl.f)+sum(data$lr.f))*(sum(data$t)+sum(data$t)+sum(data$t)))/(length(data$t)*3))

#Sigma y^2
slope[1,3]<-sum(data$f^2)-((sum(data$f)^2)/length(data$t)) 
slope[2,3]<-sum(data$nl.f^2)-((sum(data$nl.f)^2)/length(data$t))
slope[3,3]<-sum(data$le.f^2)-((sum(data$le.f)^2)/length(data$t))
slope[5,3]<-slope[1,3]+slope[2,3]+slope[3,3]
slope[6,3]<-(sum(data$f^2)+sum(data$nl.f^2)+sum(data$le.f^2))-(((sum(data$f)+sum(data$nl.f)+sum(data$le.f))^2)/(length(data$t)*3))

#residual SS
slope[1,4]<-slope[1,3]-((slope[1,2]^2)/slope[1,1]) 
slope[2,4]<-slope[2,3]-((slope[2,2]^2)/slope[2,1])
slope[3,4]<-slope[3,3]-((slope[3,2]^2)/slope[3,1])
slope[4,4]<-slope[1,4]+slope[2,4]+slope[3,4]
slope[5,4]<-slope[5,3]-((slope[5,2]^2)/slope[5,1])
slope[6,4]<-slope[6,3]-((slope[6,2]^2)/slope[6,1])

#Degrees of Freedom
slope[1,6]<-slope[1,5]-2 
slope[2,6]<-slope[2,5]-2
slope[3,6]<-slope[3,5]-2
slope[4,6]<-slope[1,6]+slope[2,6]+slope[3,6]
slope[5,6]<-(length(data$t)*3)-3-1 #minus k, where k=3, see Zar p 373
slope[6,6]<-(length(data$t)*3)-1

#regression coefficient: b=sigma(xy)/sigma(x^2)
slope[1,7]<-slope[1,2]/slope[1,1]
slope[2,7]<-slope[2,2]/slope[2,1]
slope[3,7]<-slope[3,2]/slope[3,1]
slope[5,7]<-slope[5,2]/slope[5,1]

#residual mean square for common regression = SSc/DFc (needed for Tukey HSD comparison of elevations)
slope[5,8]<-slope[5,4]/slope[5,6]

#To test whether slopes (i.e., beta) differ between lm_1, lm_2, lm_3, calculate the F statistic
beta.f_test.cam<-((slope[5,4]-slope[4,4])/(3-1))/(slope[4,4]/slope[4,6])

#Test whether the intercepts of the three regressions differ See Zar 18.5 p.375
intercept.f_test.cam<-((slope[6,4]-slope[5,4])/2)/(slope[5,4]/slope[5,6])

#Tukey HSD test for multiple comparisons among elevations (Zar 18.7 p376) 
#q=abs((mean Y1-mean Y2)-b_common(mean X1 - mean X2))/SE
#For critical values from the q-distribution, see Zar p.723
tukey<-matrix(nrow=3, ncol=8)
rownames(tukey)<-c("lm_1 v lm_2", "lm_1 v lm_3", "lm_2 v lm_3")
colnames(tukey)<-c("mean X1", "mean X2", "mean Y1", "mean Y2", "X difference","Y difference", "SE", "q") 


tukey[1,1]<-mean(data$t)
tukey[2,1]<-mean(data$t)
tukey[3,1]<-mean(data$t)

tukey[1,2]<-mean(data$t)
tukey[2,2]<-mean(data$t)
tukey[3,2]<-mean(data$t)

tukey[1,3]<-mean(data$f)
tukey[2,3]<-mean(data$f)
tukey[3,3]<-mean(data$nl.f)

tukey[1,4]<-mean(data$nl.f)
tukey[2,4]<-mean(data$le.f)
tukey[3,4]<-mean(data$le.f)

tukey[1,5]<-tukey[1,1]-tukey[1,2]
tukey[2,5]<-tukey[2,1]-tukey[2,2]
tukey[3,5]<-tukey[3,1]-tukey[3,2]

tukey[1,6]<-tukey[1,3]-tukey[1,4]
tukey[2,6]<-tukey[2,3]-tukey[2,4]
tukey[3,6]<-tukey[3,3]-tukey[3,4]

tukey[1,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[1,5]^2)/(slope[2,1]+slope[1,1]))))
tukey[2,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[2,5]^2)/(slope[3,1]+slope[1,1]))))
tukey[3,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[3,5]^2)/(slope[3,1]+slope[2,1]))))

#q -> Tukey HSD test statistic
tukey[1,8]<-abs((tukey[1,6]-(slope[5,7]*tukey[1,5]))/tukey[1,7])
tukey[2,8]<-abs((tukey[2,6]-(slope[5,7]*tukey[2,5]))/tukey[2,7])
tukey[3,8]<-abs((tukey[3,6]-(slope[5,7]*tukey[3,5]))/tukey[3,7])

cam.rls.reg<-lm_1
cam.nl.reg<-lm_2
cam.le.reg<-lm_3

reg.results.cam<-slope
tukey.results.cam<-tukey

CAM_MASTER<-data

rm(data)
rm(slope)
rm(tukey)

#######################################

#Conne - Regression

data<-CN_MASTER
lm_1<-summary(lm(data$f~data$t)) #population specific
lm_2<-summary(lm(data$nl.f~data$t)) #pooled p-content
lm_3<-summary(lm(data$le.f~data$t)) #Lyle and Elliot

plot(data$f~data$t, type="l", ylim=c(-20, 20), lwd=2)
lines(data$nl.f~data$t, type="l", lty="dashed")
lines(data$le.f~data$t, type="l", lwd=1.5)
abline(lm_1)
abline(lm_2)
abline(lm_3)

####
#Comparing the slopes the three regressions See Zar 18.4 p.373

slope<-matrix(nrow=6, ncol=8)
rownames(slope)<-c("lm_1", "lm_2", "lm_3", "pooled_reg", "common_reg", "total_reg")
colnames(slope)<-c("sigma_x^2", "sigma_xy", "sigma_y^2", "residual_ss","n", "residual_df", "b", "residual mean square (s^2)")

#Sigma x^2 (sum of squares)
slope[1,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t)) 
slope[2,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[3,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[5,1]<-slope[1,1]+slope[2,1]+slope[3,1]
slope[6,1]<-(sum(data$t^2)*3)-(((sum(data$t)^2)*3)/(length(data$t)*3))

slope[1,5]<-length(data$t) #sample size (n)
slope[2,5]<-length(data$t)
slope[3,5]<-length(data$t)
slope[6,5]<-length(data$t)*3

#Sigma xy or "sum of cross products"
slope[1,2]<-sum(data$f*data$t)-((sum(data$f)*sum(data$t))/length(data$t)) 
slope[2,2]<-sum(data$nl.f*data$t)-((sum(data$nl.f)*sum(data$t))/length(data$t)) 
slope[3,2]<-sum(data$le.f*data$t)-((sum(data$le.f)*sum(data$t))/length(data$t)) 
slope[5,2]<-slope[1,2]+slope[2,2]+slope[3,2]
slope[6,2]<-(sum(data$f*data$t)+sum(data$nl.f*data$t)+sum(data$le.f*data$t))-(((sum(data$f)+sum(data$nl.f)+sum(data$lr.f))*(sum(data$t)+sum(data$t)+sum(data$t)))/(length(data$t)*3))

#Sigma y^2
slope[1,3]<-sum(data$f^2)-((sum(data$f)^2)/length(data$t)) 
slope[2,3]<-sum(data$nl.f^2)-((sum(data$nl.f)^2)/length(data$t))
slope[3,3]<-sum(data$le.f^2)-((sum(data$le.f)^2)/length(data$t))
slope[5,3]<-slope[1,3]+slope[2,3]+slope[3,3]
slope[6,3]<-(sum(data$f^2)+sum(data$nl.f^2)+sum(data$le.f^2))-(((sum(data$f)+sum(data$nl.f)+sum(data$le.f))^2)/(length(data$t)*3))

#residual SS
slope[1,4]<-slope[1,3]-((slope[1,2]^2)/slope[1,1]) 
slope[2,4]<-slope[2,3]-((slope[2,2]^2)/slope[2,1])
slope[3,4]<-slope[3,3]-((slope[3,2]^2)/slope[3,1])
slope[4,4]<-slope[1,4]+slope[2,4]+slope[3,4]
slope[5,4]<-slope[5,3]-((slope[5,2]^2)/slope[5,1])
slope[6,4]<-slope[6,3]-((slope[6,2]^2)/slope[6,1])

#Degrees of Freedom
slope[1,6]<-slope[1,5]-2 
slope[2,6]<-slope[2,5]-2
slope[3,6]<-slope[3,5]-2
slope[4,6]<-slope[1,6]+slope[2,6]+slope[3,6]
slope[5,6]<-(length(data$t)*3)-3-1 #minus k, where k=3, see Zar p 373
slope[6,6]<-(length(data$t)*3)-1

#regression coefficient: b=sigma(xy)/sigma(x^2)
slope[1,7]<-slope[1,2]/slope[1,1]
slope[2,7]<-slope[2,2]/slope[2,1]
slope[3,7]<-slope[3,2]/slope[3,1]
slope[5,7]<-slope[5,2]/slope[5,1]

#residual mean square for common regression = SSc/DFc (needed for Tukey HSD comparison of elevations)
slope[5,8]<-slope[5,4]/slope[5,6]


#To test whether slopes (i.e., beta) differ between lm_1, lm_2, lm_3, calculate the F statistic
beta.f_test.cn<-((slope[5,4]-slope[4,4])/(3-1))/(slope[4,4]/slope[4,6])


#Test whether the intercepts of the three regressions differ See Zar 18.5 p.375
intercept.f_test.cn<-((slope[6,4]-slope[5,4])/2)/(slope[5,4]/slope[5,6])

#Tukey HSD test for multiple comparisons among elevations (Zar 18.7 p376) 
#q=abs((mean Y1-mean Y2)-b_common(mean X1 - mean X2))/SE
#For critical values from the q-distribution, see Zar p.723
tukey<-matrix(nrow=3, ncol=8)
rownames(tukey)<-c("lm_1 v lm_2", "lm_1 v lm_3", "lm_2 v lm_3")
colnames(tukey)<-c("mean X1", "mean X2", "mean Y1", "mean Y2", "X difference","Y difference", "SE", "q") 


tukey[1,1]<-mean(data$t)
tukey[2,1]<-mean(data$t)
tukey[3,1]<-mean(data$t)

tukey[1,2]<-mean(data$t)
tukey[2,2]<-mean(data$t)
tukey[3,2]<-mean(data$t)

tukey[1,3]<-mean(data$f)
tukey[2,3]<-mean(data$f)
tukey[3,3]<-mean(data$nl.f)

tukey[1,4]<-mean(data$nl.f)
tukey[2,4]<-mean(data$le.f)
tukey[3,4]<-mean(data$le.f)

tukey[1,5]<-tukey[1,1]-tukey[1,2]
tukey[2,5]<-tukey[2,1]-tukey[2,2]
tukey[3,5]<-tukey[3,1]-tukey[3,2]

tukey[1,6]<-tukey[1,3]-tukey[1,4]
tukey[2,6]<-tukey[2,3]-tukey[2,4]
tukey[3,6]<-tukey[3,3]-tukey[3,4]

tukey[1,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[1,5]^2)/(slope[2,1]+slope[1,1]))))
tukey[2,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[2,5]^2)/(slope[3,1]+slope[1,1]))))
tukey[3,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[3,5]^2)/(slope[3,1]+slope[2,1]))))

#q -> Tukey HSD test statistic
tukey[1,8]<-abs((tukey[1,6]-(slope[5,7]*tukey[1,5]))/tukey[1,7])
tukey[2,8]<-abs((tukey[2,6]-(slope[5,7]*tukey[2,5]))/tukey[2,7])
tukey[3,8]<-abs((tukey[3,6]-(slope[5,7]*tukey[3,5]))/tukey[3,7])

cn.rls.reg<-lm_1
cn.nl.reg<-lm_2
cn.le.reg<-lm_3

reg.results.cn<-slope
tukey.results.cn<-tukey

CN_MASTER<-data

rm(data)
rm(slope)
rm(tukey)

#################################
#Western Arm Brook - Regression
data<-WAB_MASTER
lm_1<-summary(lm(data$f~data$t)) #population specific
lm_2<-summary(lm(data$nl.f~data$t)) #pooled p-content
lm_3<-summary(lm(data$le.f~data$t)) #Lyle and Elliot

plot(data$f~data$t, type="l", ylim=c(-10, 10), lwd=2)
lines(data$nl.f~data$t, type="l", lty="dashed")
lines(data$le.f~data$t, type="l", lwd=1.5)
abline(lm_1)
abline(lm_2)
abline(lm_3)

####
#Comparing the slopes the three regressions See Zar 18.4 p.373

slope<-matrix(nrow=6, ncol=8)
rownames(slope)<-c("lm_1", "lm_2", "lm_3", "pooled_reg", "common_reg", "total_reg")
colnames(slope)<-c("sigma_x^2", "sigma_xy", "sigma_y^2", "residual_ss","n", "residual_df", "b", "residual mean square (s^2)")

#Sigma x^2 (sum of squares)
slope[1,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t)) 
slope[2,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[3,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[5,1]<-slope[1,1]+slope[2,1]+slope[3,1]
slope[6,1]<-(sum(data$t^2)*3)-(((sum(data$t)^2)*3)/(length(data$t)*3))

slope[1,5]<-length(data$t) #sample size (n)
slope[2,5]<-length(data$t)
slope[3,5]<-length(data$t)
slope[6,5]<-length(data$t)*3

#Sigma xy or "sum of cross products"
slope[1,2]<-sum(data$f*data$t)-((sum(data$f)*sum(data$t))/length(data$t)) 
slope[2,2]<-sum(data$nl.f*data$t)-((sum(data$nl.f)*sum(data$t))/length(data$t)) 
slope[3,2]<-sum(data$le.f*data$t)-((sum(data$le.f)*sum(data$t))/length(data$t)) 
slope[5,2]<-slope[1,2]+slope[2,2]+slope[3,2]
slope[6,2]<-(sum(data$f*data$t)+sum(data$nl.f*data$t)+sum(data$le.f*data$t))-(((sum(data$f)+sum(data$nl.f)+sum(data$lr.f))*(sum(data$t)+sum(data$t)+sum(data$t)))/(length(data$t)*3))

#Sigma y^2
slope[1,3]<-sum(data$f^2)-((sum(data$f)^2)/length(data$t)) 
slope[2,3]<-sum(data$nl.f^2)-((sum(data$nl.f)^2)/length(data$t))
slope[3,3]<-sum(data$le.f^2)-((sum(data$le.f)^2)/length(data$t))
slope[5,3]<-slope[1,3]+slope[2,3]+slope[3,3]
slope[6,3]<-(sum(data$f^2)+sum(data$nl.f^2)+sum(data$le.f^2))-(((sum(data$f)+sum(data$nl.f)+sum(data$le.f))^2)/(length(data$t)*3))

#residual SS
slope[1,4]<-slope[1,3]-((slope[1,2]^2)/slope[1,1]) 
slope[2,4]<-slope[2,3]-((slope[2,2]^2)/slope[2,1])
slope[3,4]<-slope[3,3]-((slope[3,2]^2)/slope[3,1])
slope[4,4]<-slope[1,4]+slope[2,4]+slope[3,4]
slope[5,4]<-slope[5,3]-((slope[5,2]^2)/slope[5,1])
slope[6,4]<-slope[6,3]-((slope[6,2]^2)/slope[6,1])

#Degrees of Freedom
slope[1,6]<-slope[1,5]-2 
slope[2,6]<-slope[2,5]-2
slope[3,6]<-slope[3,5]-2
slope[4,6]<-slope[1,6]+slope[2,6]+slope[3,6]
slope[5,6]<-(length(data$t)*3)-3-1 #minus k, where k=3, see Zar p 373
slope[6,6]<-(length(data$t)*3)-1

#regression coefficient: b=sigma(xy)/sigma(x^2)
slope[1,7]<-slope[1,2]/slope[1,1]
slope[2,7]<-slope[2,2]/slope[2,1]
slope[3,7]<-slope[3,2]/slope[3,1]
slope[5,7]<-slope[5,2]/slope[5,1]

#residual mean square for common regression = SSc/DFc (needed for Tukey HSD comparison of elevations)
slope[5,8]<-slope[5,4]/slope[5,6]


#To test whether slopes (i.e., beta) differ between lm_1, lm_2, lm_3, calculate the F statistic
beta.f_test.wab<-((slope[5,4]-slope[4,4])/(3-1))/(slope[4,4]/slope[4,6])


#Test whether the intercepts of the three regressions differ See Zar 18.5 p.375
intercept.f_test.wab<-((slope[6,4]-slope[5,4])/2)/(slope[5,4]/slope[5,6])

#Tukey HSD test for multiple comparisons among elevations (Zar 18.7 p376) 
#q=abs((mean Y1-mean Y2)-b_common(mean X1 - mean X2))/SE
#For critical values from the q-distribution, see Zar p.723
tukey<-matrix(nrow=3, ncol=8)
rownames(tukey)<-c("lm_1 v lm_2", "lm_1 v lm_3", "lm_2 v lm_3")
colnames(tukey)<-c("mean X1", "mean X2", "mean Y1", "mean Y2", "X difference","Y difference", "SE", "q") 


tukey[1,1]<-mean(data$t)
tukey[2,1]<-mean(data$t)
tukey[3,1]<-mean(data$t)

tukey[1,2]<-mean(data$t)
tukey[2,2]<-mean(data$t)
tukey[3,2]<-mean(data$t)

tukey[1,3]<-mean(data$f)
tukey[2,3]<-mean(data$f)
tukey[3,3]<-mean(data$nl.f)

tukey[1,4]<-mean(data$nl.f)
tukey[2,4]<-mean(data$le.f)
tukey[3,4]<-mean(data$le.f)

tukey[1,5]<-tukey[1,1]-tukey[1,2]
tukey[2,5]<-tukey[2,1]-tukey[2,2]
tukey[3,5]<-tukey[3,1]-tukey[3,2]

tukey[1,6]<-tukey[1,3]-tukey[1,4]
tukey[2,6]<-tukey[2,3]-tukey[2,4]
tukey[3,6]<-tukey[3,3]-tukey[3,4]

tukey[1,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[1,5]^2)/(slope[2,1]+slope[1,1]))))
tukey[2,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[2,5]^2)/(slope[3,1]+slope[1,1]))))
tukey[3,7]<-sqrt((slope[5,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[3,5]^2)/(slope[3,1]+slope[2,1]))))

#q -> Tukey HSD test statistic
tukey[1,8]<-abs((tukey[1,6]-(slope[5,7]*tukey[1,5]))/tukey[1,7])
tukey[2,8]<-abs((tukey[2,6]-(slope[5,7]*tukey[2,5]))/tukey[2,7])
tukey[3,8]<-abs((tukey[3,6]-(slope[5,7]*tukey[3,5]))/tukey[3,7])

wab.rls.reg<-lm_1
wab.nl.reg<-lm_2
wab.le.reg<-lm_3

reg.results.wab<-slope
tukey.results.wab<-tukey

WAB_MASTER<-data

rm(data)
rm(slope)
rm(tukey)

##################
#Write tables of regression and Tukey results

write.table(reg.results.cam, file = "")
write.table(reg.results.cn, file = "")
write.table(reg.results.wab, file="")

write.table(tukey.results.cam, file="")
write.table(tukey.results.cn, file="")
write.table(tukey.results.wab, file="")

#write table with F values for slopes and elevations
fstat<-matrix(nrow=6, ncol=1)
rownames(fstat)<-c("cam slope", "cam elevation", "cn slope", "cn elevation", "wab slope", "wab elevation")
colnames(fstat)<-c("F") 

fstat[1,1]<-beta.f_test.cam
fstat[2,1]<-intercept.f_test.cam
fstat[3,1]<-beta.f_test.cn
fstat[4,1]<-intercept.f_test.cn
fstat[5,1]<-beta.f_test.wab
fstat[6,1]<-intercept.f_test.wab



write.table(fstat, file="")

#Write table of medians and standard deviations
medians<-matrix(nrow=9, ncol=11)
colnames(medians)<-c("River", "Value used", "median", "st dev", "slope", "intercept", "r-squared", "F-test slopes", "p-value slopes", "F-test elevation", "p-value slopes")

medians[1,1]<-"Campbellton"
medians[4,1]<-"Conne"
medians[7,1]<-"Western Arm"

medians[1,2]<-"river specific"
medians[2,2]<-"pooled"
medians[3,2]<-"Lyle and Elliot"
medians[4,2]<-"river specific"
medians[5,2]<-"pooled"
medians[6,2]<-"Lyle and Elliot"
medians[7,2]<-"river specific"
medians[8,2]<-"pooled"
medians[9,2]<-"Lyle and Elliot"

medians[1,3]<-median(CAM_MASTER$f)
medians[2,3]<-median(CAM_MASTER$nl.f)
medians[3,3]<-median(CAM_MASTER$le.f)
medians[4,3]<-median(CN_MASTER$f)
medians[5,3]<-median(CN_MASTER$nl.f)
medians[6,3]<-median(CN_MASTER$le.f)
medians[7,3]<-median(WAB_MASTER$f)
medians[8,3]<-median(WAB_MASTER$nl.f)
medians[9,3]<-median(WAB_MASTER$le.f)

medians[1,4]<-sd(CAM_MASTER$f)
medians[2,4]<-sd(CAM_MASTER$nl.f)
medians[3,4]<-sd(CAM_MASTER$le.f)
medians[4,4]<-sd(CN_MASTER$f)
medians[5,4]<-sd(CN_MASTER$nl.f)
medians[6,4]<-sd(CN_MASTER$le.f)
medians[7,4]<-sd(WAB_MASTER$f)
medians[8,4]<-sd(WAB_MASTER$nl.f)
medians[9,4]<-sd(WAB_MASTER$le.f)

#slopes
medians[1,5]<-reg.results.cam[1,7]
medians[2,5]<-reg.results.cam[2,7]
medians[3,5]<-reg.results.cam[3,7]
medians[4,5]<-reg.results.cn[1,7]
medians[5,5]<-reg.results.cn[2,7]
medians[6,5]<-reg.results.cn[3,7]
medians[7,5]<-reg.results.wab[1,7]
medians[8,5]<-reg.results.wab[2,7]
medians[9,5]<-reg.results.wab[3,7]

#intercepts
medians[1,6]<-cam.rls.reg$coefficients[1]
medians[2,6]<-cam.nl.reg$coefficients[1]
medians[3,6]<-cam.le.reg$coefficients[1]
medians[4,6]<-cn.rls.reg$coefficients[1]
medians[5,6]<-cn.nl.reg$coefficients[1]
medians[6,6]<-cn.le.reg$coefficients[1]
medians[7,6]<-wab.rls.reg$coefficients[1]
medians[8,6]<-wab.nl.reg$coefficients[1]
medians[9,6]<-wab.le.reg$coefficients[1] 

#R-squared
medians[1,7]<-cam.rls.reg$r.squared
medians[2,7]<-cam.nl.reg$r.squared
medians[3,7]<-cam.le.reg$r.squared
medians[4,7]<-cn.rls.reg$r.squared
medians[5,7]<-cn.nl.reg$r.squared
medians[6,7]<-cn.le.reg$r.squared
medians[7,7]<-wab.rls.reg$r.squared
medians[8,7]<-wab.nl.reg$r.squared
medians[9,7]<-wab.le.reg$r.squared

#F-test for differences in slopes within
medians[1,8]<-NA
medians[2,8]<-NA
medians[3,8]<-beta.f_test.cam
medians[4,8]<-NA
medians[5,8]<-NA
medians[6,8]<-beta.f_test.cn
medians[7,8]<-NA
medians[8,8]<-NA
medians[9,8]<-beta.f_test.wab

medians[1,10]<-NA
medians[2,10]<-NA
medians[3,10]<-intercept.f_test.cam
medians[4,10]<-NA
medians[5,10]<-NA
medians[6,10]<-intercept.f_test.cn
medians[7,10]<-NA
medians[8,10]<-NA
medians[9,10]<-intercept.f_test.wab



################################################################################################
#FIGURE 4 IN EBEL, LEROUX, ROBERTSON, DEMPSON - Time series of P flux calculated with three different nutrient concentration values

x11(height=8, width=5)
par(mfrow=c(3,1))
par(oma=c(3,3,3,3)) #sets outer margins
par(mar=c(0,2,1,2))
par(las=1)
par(mgp=c(1, 1, 0))

plot(CAM_MASTER$f~CAM_MASTER$yr, type="l", pch=21, lwd=1.5, lty="solid", xlab="", ylab="", xaxt="n", ylim=c(-20,40), xlim=c(1992, 2013), cex.axis=1.5)
lines(CAM_MASTER$nl.f~CAM_MASTER$yr, type="l", pch=21, lwd=1.5, lty="longdash", xaxt="n")
lines(CAM_MASTER$le.f~CAM_MASTER$yr, type="l", pch=21, lwd=1.5, lty="dotted", xaxt="n")
abline(h=0, lwd=2)
legend("topleft", legend=c("River-specific", "Regional", "Extracted from literature"),lwd=1.5, lty=c("solid", "longdash", "dashed"), pt.cex=2, cex=1.25, bty="n")

plot(CN_MASTER$f~CN_MASTER$yr, type="l", pch=21, lwd=1.5, lty="solid", xlab="", ylab="", xaxt="n", ylim=c(-20,40), xlim=c(1992,2013), cex.axis=1.5)
lines(CN_MASTER$nl.f~CN_MASTER$yr, type="l", pch=21, lwd=1.5,lty="longdash", xaxt="n")
lines(CN_MASTER$le.f~CN_MASTER$yr, type="l", pch=21, lwd=1.5, lty="dotted", xaxt="n")
abline(h=0, lwd=2)

plot(WAB_MASTER$f~WAB_MASTER$yr, type="l", pch=21, lwd=1.5, lty="solid", xlab="", ylab="", ylim=c(-20,40), xlim=c(1992,2013), cex.axis=1.5)
lines(WAB_MASTER$nl.f~WAB_MASTER$yr, type="l", pch=21, lwd=1.5,lty="longdash", xaxt="n")
lines(WAB_MASTER$le.f~WAB_MASTER$yr, type="l", pch=21, lwd=1.5, lty="dotted", xaxt="n")
abline(h=0, lwd=2)


#Write table of mean count, mass, and length with standard deviations
summary<-matrix(nrow=9, ncol=8)
colnames(summary)<-c("Life Stage", "River", "Mean count", "st dev", "Mean Mass", "St dev", "mean length", "std dev")

summary[1,1]<-"small adult"
summary[4,1]<-"large adult"
summary[7,1]<-"smolt"

summary[1,2]<-"Campbellton"
summary[2,2]<-"Conne"
summary[3,2]<-"Western Arm"
summary[4,2]<-"Campbellton"
summary[5,2]<-"Conne"
summary[6,2]<-"Western Arm"
summary[7,2]<-"Campbellton"
summary[8,2]<-"Conne"
summary[9,2]<-"Western Arm"

summary[1,3]<- mean(CAM$A_COUNT_SM, na.rm=T)
summary[2,3]<- mean(CN$A_COUNT_SM, na.rm=T)
summary[3,3]<- mean(WAB$A_COUNT_SM, na.rm=T)
summary[4,3]<- mean(CAM$A_COUNT_LG, na.rm=T)
summary[5,3]<- mean(CN$A_COUNT_LG, na.rm=T)
summary[6,3]<- mean(WAB$A_COUNT_LG, na.rm=T)
summary[7,3]<- mean(CAM$S_COUNT, na.rm=T)
summary[8,3]<- mean(CN$S_COUNT, na.rm=T)
summary[9,3]<- mean(WAB$S_COUNT, na.rm=T)

summary[1,4]<- sd(CAM$A_COUNT_SM, na.rm=T)
summary[2,4]<- sd(CN$A_COUNT_SM, na.rm=T)
summary[3,4]<- sd(WAB$A_COUNT_SM, na.rm=T)
summary[4,4]<- sd(CAM$A_COUNT_LG, na.rm=T)
summary[5,4]<- sd(CN$A_COUNT_LG, na.rm=T)
summary[6,4]<- sd(WAB$A_COUNT_LG, na.rm=T)
summary[7,4]<- sd(CAM$S_COUNT, na.rm=T)
summary[8,4]<- sd(CN$S_COUNT, na.rm=T)
summary[9,4]<- sd(WAB$S_COUNT, na.rm=T)

### Mean mass of smolt (pooled over 20 years) See adult.weights section for adult masses and lengths
summary[7,5]<- mean(CAM$S_MASS, na.rm=T)
summary[8,5]<- mean(CN$S_MASS, na.rm=T)
summary[9,5]<- mean(WAB$S_MASS, na.rm=T)


summary[7,6]<- sd(CAM$S_MASS, na.rm=T)
summary[8,6]<- sd(CN$S_MASS, na.rm=T)
summary[9,6]<- sd(WAB$S_MASS, na.rm=T)

summary[7,7]<- mean(CAM$S_LENGTH, na.rm=T)
summary[8,7]<- mean(CN$S_LENGTH, na.rm=T)
summary[9,7]<- mean(WAB$S_LENGTH, na.rm=T)


summary[7,8]<- sd(CAM$S_LENGTH, na.rm=T)
summary[8,8]<- sd(CN$S_LENGTH, na.rm=T)
summary[9,8]<- sd(WAB$S_LENGTH, na.rm=T)

###########################################################################################
#Appendix C Table 1

total<-matrix(nrow=3, ncol=7)
colnames(total)<-c("River", "f>0(years)", "Total.import", "Total.Net.Import", "total.smolt.export", "%import", "%netimport")

total[1,1]<-"Campbellton"
total[2,1]<-"Conne"
total[3,1]<-"Western Arm"

total[1,2]<-8
total[2,2]<-2
total[3,2]<-9

total[1,3]<-sum(CAM_MASTER$import.sp.sm, CAM_MASTER$import.sp.lg)
total[2,3]<-sum(CN_MASTER$import.sp.sm, CN_MASTER$import.sp.lg)
total[3,3]<-sum(WAB_MASTER$import.sp.sm, WAB_MASTER$import.sp.lg)

total[1,4]<-sum(CAM_MASTER$netimport.sm, CAM_MASTER$netimport.lg)
total[2,4]<-sum(CN_MASTER$netimport.sm, CN_MASTER$netimport.lg)
total[3,4]<-sum(WAB_MASTER$netimport.sm, WAB_MASTER$netimport.lg)

total[1,5]<-sum(CAM_MASTER$exports)
total[2,5]<-sum(CN_MASTER$exports)
total[3,5]<-sum(WAB_MASTER$exports)

total[1,6]<-sum(CAM_MASTER$exports)/sum(CAM_MASTER$import.sp.sm, CAM_MASTER$import.sp.lg)
total[2,6]<-sum(CN_MASTER$exports)/sum(CN_MASTER$import.sp.sm, CN_MASTER$import.sp.lg)
total[3,6]<-sum(WAB_MASTER$exports)/sum(WAB_MASTER$import.sp.sm, WAB_MASTER$import.sp.lg)

total[1,7]<-sum(CAM_MASTER$exports)/sum(CAM_MASTER$netimport.sm, CAM_MASTER$netimport.lg)
total[2,7]<-sum(CN_MASTER$exports)/sum(CN_MASTER$netimport.sm, CN_MASTER$netimport.lg)
total[3,7]<-sum(WAB_MASTER$exports)/sum(WAB_MASTER$netimport.sm, WAB_MASTER$netimport.lg)

###################################################################################################################################
#Table of number of spawners (APPENDIX A)

spawners<-matrix(nrow=6, ncol=4)
colnames(spawners)<-c("strm", "ls", "mean spawners", "sd")
spawners[1,1]<-"Campbellton"; spawners[1,2]<-"small"; spawners[1,3]<-mean(CAM_MASTER$sp.sm); spawners[1,4]<-sd(CAM_MASTER$sp.sm)
spawners[2,1]<-""; spawners[1,2]<-"large"; spawners[2,3]<-mean(CAM_MASTER$sp.lg); spawners[2,4]<-sd(CAM_MASTER$sp.lg)

spawners[3,1]<-"Conne"; spawners[3,2]<-"small"; spawners[3,3]<-mean(CN_MASTER$sp.sm); spawners[3,4]<-sd(CN_MASTER$sp.sm)
spawners[4,1]<-""; spawners[4,2]<-"large"; spawners[4,3]<-mean(CN_MASTER$sp.lg); spawners[4,4]<-sd(CN_MASTER$sp.lg)

spawners[5,1]<-"Western Arm"; spawners[5,2]<-"small"; spawners[5,3]<-mean(WAB_MASTER$sp.sm); spawners[5,4]<-sd(WAB_MASTER$sp.sm)
spawners[6,1]<-""; spawners[6,2]<-"large"; spawners[6,3]<-mean(WAB_MASTER$sp.lg); spawners[6,4]<-sd(WAB_MASTER$sp.lg)

#################################################################################################
#APPENDIX D - Variable Overwinter survival
# This code takes the form of the flux section of code above but with different overwinter survival values. It requires that the same codes be run prior. 

salmon <- read.csv("C:/Users/Jonathan/Desktop/DATA & CODE/MUN_Datasets/Data/Flux data/MASTER/p.flux.test.csv")

kelt.survival<-c(0.7429, 0.7674, 0.7262, 0.7499, 0.5684, 0.5281, 0.4558, 0.5735, 0.4650, 0.3475, 0.5801, 
                 0.5320, 0.7110, 0.4833, 0.3109, 0.6416, 0.4453) # M Robertson unpublished data

#kelt survival will be the mean + 1sd, and mean - 1sd. Mean survival on Campbellton is 0.566, sd = 0.141, 
#therefore the code will calculate flux with a survival of 0.707 and 0.425 


#Break Master salmon count data frame into subsets by stream
data<-salmon
data$AMS<-weight$ww.s
data$AML<-weight$ww.l
data$ALS<-weight$fl.s
data$ALL<-weight$fl.l

CAM<-subset(data, STRM=="CAM")
CN<-subset(data, STRM=="CN")
WAB<-subset(data, STRM=="WAB")

#Replace missing weight values with mean values
CAM$ams<-ifelse(is.nan(CAM$AMS), mean(CAM$AMS, na.rm=TRUE), CAM$AMS)
CAM$aml<-ifelse(is.nan(CAM$AML), mean(CAM$AML, na.rm=TRUE), CAM$AML)
CAM$als<-ifelse(is.nan(CAM$ALS), mean(CAM$ALS, na.rm=TRUE), CAM$ALS)
CAM$all<-ifelse(is.nan(CAM$ALL), mean(CAM$ALL, na.rm=TRUE), CAM$ALL)
CAM$sm<-ifelse(CAM$S_M==-1, mean(CAM$S_MASS, na.rm=TRUE), CAM$S_M)


CN$ams<-ifelse(is.nan(CN$AMS), mean(CN$AMS, na.rm=TRUE), CN$AMS)
CN$aml<-ifelse(is.nan(CN$AML), mean(cn.large.ww, na.rm=TRUE), CN$AML)#uses values from 6 fish. cn.large.ww is found in p.flux.adult.weights.R
CN$als<-ifelse(is.nan(CN$ALS), mean(CN$ALS, na.rm=TRUE), CN$ALS)
CN$all<-ifelse(is.nan(CN$ALL), mean(cn.large.fl, na.rm=TRUE), CN$ALL)#uses values from 6 fish. cn.large.fl is found in p.flux.adult.weights.R
CN$sm<-ifelse(CN$S_M==-1, mean(CN$S_MASS, na.rm=TRUE), CN$S_M)


WAB$ams<-ifelse(is.nan(WAB$AMS), mean(WAB$AMS, na.rm=TRUE), WAB$AMS)
WAB$aml<-ifelse(is.nan(WAB$AML), mean(WAB$AML, na.rm=TRUE), WAB$AML)
WAB$als<-ifelse(is.nan(WAB$ALS), mean(WAB$ALS, na.rm=TRUE), WAB$ALS)
WAB$all<-ifelse(is.nan(WAB$ALL), mean(WAB$ALL, na.rm=TRUE), WAB$ALL)
WAB$sm<-ifelse(WAB$S_M==-1, mean(WAB$S_MASS, na.rm=TRUE), WAB$S_M)

rm(data)
###################################################################################################
#Campbellton with high survival (70%, mean survival PLUS 1 sd)
#Changed from large.fish.contribution.R to separate counts and # spawners (as provided by DFO). # small spawners = sp.sm, # large spawners = sp.lg
data<-CAM

CAM_PARAMETERS<-data.frame(strm=data$STRM, yr=data$YR, 
                           acs=data$A_COUNT_SM, acl=data$A_COUNT_LG, #Adult counts 
                           sp.sm=data$A_SPAWNER_SM, sp.lg=data$A_SPAWNER_LG,#Spawner counts
                           sc=data$S_COUNT, #smolt count 
                           ams=data$ams, aml=data$aml, sm=data$sm,#adult and smolt mass data
                           als=data$als, all=data$all, # adult lengths
                           #Stream and life stage specific P contents
                           anut=(rep((rls.means[1,1]/100),length(data$YR))), #adult nutrient concentration
                           knut=(rep((rls.means[1,3]/100),length(data$YR))), #kelt nutrient concentration
                           snut=(rep((rls.means[1,5]/100),length(data$YR))), #smolt nutrient concentration
                           
                           #Post spawn survival and mass loss
                           ksurv = rep(0.70,length(data$YR)), 
                           kmp.s=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als*10))))),
                           kmp.l=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$all*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$all*10)))))
)
rm(data)


#Calculate Import, Export, Flux using 2013 river specific P-content, pooled from three NL rivers, and values from Lyle and Elliot(1998)

data<-CAM_PARAMETERS

data$t=c(1:length(data$yr))
data$ac.sum=c(sapply(1:length(data$yr), function(x)"+"(data$acs[x], data$acl[x]))) #Total number of adults passing through counting fence
data$sp.sum=c(sapply(1:length(data$yr), function(x)"+"(data$sp.sm[x], data$sp.lg[x]))) #Number of adults spawning (Count - known recreational angler harvests)


#flux using river-specific measurements

data$import.c.sm=(data$acs*data$ams*data$anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$import.c.lg= (data$acl*data$aml*data$anut) #Maximum potential import by large adults (uses COUNTS)

data$import.sp.sm = (data$sp.sm*data$ams*data$anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$import.sp.lg = (data$sp.lg*data$aml*data$anut) #Actual import after accounting for recreational angling harvest of large salmon

data$exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$knut)

data$netimport.sm = data$import.sp.sm-data$exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$netimport.lg=data$import.sp.lg-data$exportk.lg

data$exports = data$sc * data$sm*data$snut #Calculates Export by smolt

data$f=(data$netimport.sm + data$netimport.lg) - data$exports #Calculates nutrient flux




cam.high<-data
cam.high.parameters<-CAM_PARAMETERS
cam.high
rm(data)
rm(CAM_PARAMETERS)
################################################################################################

#Mean overwintersurvival MINUS 1 SD

data<-CAM

CAM_PARAMETERS<-data.frame(strm=data$STRM, yr=data$YR, 
                           acs=data$A_COUNT_SM, acl=data$A_COUNT_LG, #Adult counts 
                           sp.sm=data$A_SPAWNER_SM, sp.lg=data$A_SPAWNER_LG,#Spawner counts
                           sc=data$S_COUNT, #smolt count 
                           ams=data$ams, aml=data$aml, sm=data$sm,#adult and smolt mass data
                           als=data$als, all=data$all, # adult lengths
                           #Stream and life stage specific P contents
                           anut=(rep((rls.means[1,1]/100),length(data$YR))), #adult nutrient concentration
                           knut=(rep((rls.means[1,3]/100),length(data$YR))), #kelt nutrient concentration
                           snut=(rep((rls.means[1,5]/100),length(data$YR))), #smolt nutrient concentration
                           
                           #Post spawn survival and mass loss
                           ksurv = rep(0.43,length(data$YR)), 
                           kmp.s=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als*10))))),
                           kmp.l=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$all*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$all*10)))))
)
rm(data)


#Calculate Import, Export, Flux using 2013 river specific P-content, pooled from three NL rivers, and values from Lyle and Elliot(1998)

data<-CAM_PARAMETERS

data$t=c(1:length(data$yr))
data$ac.sum=c(sapply(1:length(data$yr), function(x)"+"(data$acs[x], data$acl[x]))) #Total number of adults passing through counting fence
data$sp.sum=c(sapply(1:length(data$yr), function(x)"+"(data$sp.sm[x], data$sp.lg[x]))) #Number of adults spawning (Count - known recreational angler harvests)


#flux using river-specific measurements

data$import.c.sm=(data$acs*data$ams*data$anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.25Sept14.R
data$import.c.lg= (data$acl*data$aml*data$anut) #Maximum potential import by large adults (uses COUNTS)

data$import.sp.sm = (data$sp.sm*data$ams*data$anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$import.sp.lg = (data$sp.lg*data$aml*data$anut) #Actual import after accounting for recreational angling harvest of large salmon

data$exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$knut)

data$netimport.sm = data$import.sp.sm-data$exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$netimport.lg=data$import.sp.lg-data$exportk.lg

data$exports = data$sc * data$sm*data$snut #Calculates Export by smolt

data$f=(data$netimport.sm + data$netimport.lg) - data$exports #Calculates nutrient flux

cam.low<-data
cam.low.parameters<-CAM_PARAMETERS
cam.low
rm(data)

################################################################################################

#Annual survival measurements

data<-CAM

CAM_PARAMETERS<-data.frame(strm=data$STRM, yr=data$YR, 
                           acs=data$A_COUNT_SM, acl=data$A_COUNT_LG, #Adult counts 
                           sp.sm=data$A_SPAWNER_SM, sp.lg=data$A_SPAWNER_LG,#Spawner counts
                           sc=data$S_COUNT, #smolt count 
                           ams=data$ams, aml=data$aml, sm=data$sm,#adult and smolt mass data
                           als=data$als, all=data$all, # adult lengths
                           #Stream and life stage specific P contents
                           anut=(rep((rls.means[1,1]/100),length(data$YR))), #adult nutrient concentration
                           knut=(rep((rls.means[1,3]/100),length(data$YR))), #kelt nutrient concentration
                           snut=(rep((rls.means[1,5]/100),length(data$YR))), #smolt nutrient concentration
                           
                           #Post spawn mass loss
                           
                           
                           kmp.s=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$als*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$als*10))))),
                           kmp.l=(10^((k.regression$coefficients[1]+(k.regression$coefficients[2]*log10(data$all*10))))/ (10^(a.regression$coefficients[1]+(a.regression$coefficients[2]*log10(data$all*10)))))
)
rm(data)

CAM_PARAMETERS$survival<-c(NA, 0.7429, 0.7674, 0.7262, 0.7499, NA, 0.5684, 0.5281, 0.4558, 0.5735, 0.4650, 0.3475, 0.5801, 0.5320, 0.7110, 0.4833, 0.3109, .3075, 0.6416, 0.4453)
CAM_PARAMETERS$ksurv<-ifelse(is.na(CAM_PARAMETERS$survival), mean(CAM_PARAMETERS$survival, na.rm=TRUE), CAM_PARAMETERS$survival) 

######

data<-CAM_PARAMETERS

data$t=c(1:length(data$yr))
data$ac.sum=c(sapply(1:length(data$yr), function(x)"+"(data$acs[x], data$acl[x]))) #Total number of adults passing through counting fence
data$sp.sum=c(sapply(1:length(data$yr), function(x)"+"(data$sp.sm[x], data$sp.lg[x]))) #Number of adults spawning (Count - known recreational angler harvests)


#flux using river-specific measurements

data$import.c.sm=(data$acs*data$ams*data$anut) #Maximum potential import by small adults (uses COUNTS), uses river-specific nutrient values -> see "rls.means" in asbc.master.R
data$import.c.lg= (data$acl*data$aml*data$anut) #Maximum potential import by large adults (uses COUNTS)

data$import.sp.sm = (data$sp.sm*data$ams*data$anut) # Actual import after accounting for recreational angling harvest of small small salmon
data$import.sp.lg = (data$sp.lg*data$aml*data$anut) #Actual import after accounting for recreational angling harvest of large salmon

data$exportk.sm =(data$sp.sm* data$ksurv * data$ams * data$kmp.s*data$knut) #Export by kelt calculated by applying overwinter survival rate and the # of spawners
data$exportk.lg=(data$sp.lg * data$ksurv * data$aml * data$kmp.l*data$knut)

data$netimport.sm = data$import.sp.sm-data$exportk.sm #Net Import = (Adult Import - kelt export), which uses number of spawners, not counts.
data$netimport.lg=data$import.sp.lg-data$exportk.lg

data$exports = data$sc * data$sm*data$snut #Calculates Export by smolt

data$f=(data$netimport.sm + data$netimport.lg) - data$exports #Calculates nutrient flux

cam.variable<-data
cam.var.parameters<-CAM_PARAMETERS
cam.variable
rm(data)

######################################################################################################################################################


######################################################################################################################################
#FIGURE D1 IN EBEL LEROUX ROBERTSON DEMPSON

data<-data.frame(cbind(yr=cam.variable$yr,t=cam.variable$t, f.low=cam.low$f, f.high=cam.high$f, f.actual=cam.variable$f, f.mean=CAM_MASTER$f))

x11(height=5, width=6)
par(mfrow=c(1,1))
par(oma=c(3,3,3,3)) #sets outer margins
par(mar=c(0,2,1,2))
par(las=1)
par(mgp=c(1, 1, 0))

plot(data$f.mean~data$yr, type="l", pch=21, lwd=2, lty="solid", xlab="", ylab="", ylim=c(-20,30), xlim=c(1992, 2013), cex.axis=1.5)
lines(data$f.high~data$yr, type="l", pch=21, lwd=2, lty="longdash", xaxt="n")
lines(data$f.low~data$yr, type="l", pch=21, lwd=2, lty="dotted", xaxt="n")
lines(data$f.actual~data$yr, type="l", pch=21, lwd=2, lty="twodash", xaxt="n")

abline(h=0, lwd=3)
legend("topleft", legend=c("Mean survival", "High survival", "Low survival", "Actual"), lty=c("solid", "longdash", "dotted", "twodash"),lwd=2, pt.cex=2, cex=1.25, bty="n")

##################################################################################
##Test for differences in elevation of k regressions (See Zar 5th Edition section 18.4 p.373)

lm_1<-summary(lm(data$f.high~data$t)) #high over winter survial
lm_2<-summary(lm(data$f.low~data$t)) #low overwinter survival
lm_3<-summary(lm(data$f.actual~data$t)) #actual overwinter survival
lm_4<-summary(lm(data$f.mean~data$t)) #mean overwinter survival 

####
#Comparing the slopes the four regressions See Zar 5th Edition section 18.4 p.373

slope<-matrix(nrow=7, ncol=8)
rownames(slope)<-c("lm_1", "lm_2", "lm_3", "lm_4", "pooled_reg", "common_reg", "total_reg")
colnames(slope)<-c("sigma_x^2", "sigma_xy", "sigma_y^2", "residual_ss","n", "residual_df", "b", "residual mean square (s^2)")

#Sigma x^2 (sum of squares)
slope[1,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t)) 
slope[2,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[3,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
slope[4,1]<-sum(data$t^2)-((sum(data$t)^2)/length(data$t))
#no calculation for pooled regression
slope[6,1]<-slope[1,1]+slope[2,1]+slope[3,1]+slope[4,1]
slope[7,1]<-(sum(data$t^2)*4)-(((sum(data$t)^2)*4)/(length(data$t)*4))

#sample size (n)
slope[1,5]<-length(data$t) 
slope[2,5]<-length(data$t)
slope[3,5]<-length(data$t)
slope[4,5]<-length(data$t)
#no calculation for pooled regression or common regression
slope[7,5]<-length(data$t)*4

#Sigma xy or "sum of cross products"
slope[1,2]<-sum(data$f.high*data$t)-((sum(data$f.high)*sum(data$t))/length(data$t)) 
slope[2,2]<-sum(data$f.low*data$t)-((sum(data$f.low)*sum(data$t))/length(data$t)) 
slope[3,2]<-sum(data$f.actual*data$t)-((sum(data$f.actual)*sum(data$t))/length(data$t))
slope[4,2]<-sum(data$f.mean*data$t)-((sum(data$f.mean)*sum(data$t))/length(data$t))

slope[6,2]<-slope[1,2]+slope[2,2]+slope[3,2]+slope[4,2]
slope[7,2]<-(sum(data$f.high*data$t)+sum(data$f.low*data$t)+sum(data$f.actual*data$t))-(((sum(data$f.high)+sum(data$f.low)+sum(data$f.actual)+sum(data$f.mean))*(sum(data$t)+sum(data$t)+sum(data$t)+sum(data$t)))/(length(data$t)*4))

#Sigma y^2
slope[1,3]<-sum(data$f.high^2)-((sum(data$f.high)^2)/length(data$t)) 
slope[2,3]<-sum(data$f.low^2)-((sum(data$f.low)^2)/length(data$t))
slope[3,3]<-sum(data$f.actual^2)-((sum(data$f.actual)^2)/length(data$t))
slope[4,3]<-sum(data$f.mean^2)-((sum(data$f.mean)^2)/length(data$t))

slope[6,3]<-slope[1,3]+slope[2,3]+slope[3,3]+slope[4,3]
slope[7,3]<-(sum(data$f.high^2)+sum(data$f.low^2)+sum(data$f.actual^2)+sum(data$f.mean^2))-(((sum(data$f.high)+sum(data$f.low)+sum(data$f.actual)+sum(data$f.mean))^2)/(length(data$t)*4))

#residual SS
slope[1,4]<-slope[1,3]-((slope[1,2]^2)/slope[1,1]) 
slope[2,4]<-slope[2,3]-((slope[2,2]^2)/slope[2,1])
slope[3,4]<-slope[3,3]-((slope[3,2]^2)/slope[3,1])
slope[4,4]<-slope[4,3]-((slope[4,2]^2)/slope[4,1])
slope[5,4]<-slope[1,4]+slope[2,4]+slope[3,4]+slope[4,4]#pooled SS

slope[6,4]<-slope[6,3]-((slope[6,2]^2)/slope[6,1])#common SS
slope[7,4]<-slope[7,3]-((slope[7,2]^2)/slope[7,1])

#Degrees of Freedom
slope[1,6]<-slope[1,5]-2 
slope[2,6]<-slope[2,5]-2
slope[3,6]<-slope[3,5]-2
slope[4,6]<-slope[4,5]-2
slope[5,6]<-slope[1,6]+slope[2,6]+slope[3,6]+slope[4,6]
slope[6,6]<-(length(data$t)*4)-4-1 #minus k, where k=4, see Zar p 373; DFc
slope[7,6]<-(length(data$t)*4)-2 ##### NEED TO CHECK PREVIOUS REGRESSION BECAUSE THIS SHOULD BE MINUS 2 not MINUS 1

#regression coefficient: b=sigma(xy)/sigma(x^2)
slope[1,7]<-slope[1,2]/slope[1,1]
slope[2,7]<-slope[2,2]/slope[2,1]
slope[3,7]<-slope[3,2]/slope[3,1]
slope[4,7]<-slope[4,2]/slope[4,1]
slope[6,7]<-slope[6,2]/slope[6,1]#for common regression

#residual mean square for common regression = SSc/DFc (needed for Tukey HSD comparison of elevations)
slope[6,8]<-slope[6,4]/slope[6,6]

#To test whether slopes (i.e., beta) differ between lm_1, lm_2, lm_3,lm_4, calculate the F statistic. F = ((SSc - SSp)/k-1)/(SSp/DFp), p 373
beta.f.test<-((slope[6,4]-slope[5,4])/(4-1))/(slope[5,4]/slope[5,6])

#Test whether the intercepts of the three regressions differ See Zar 18.5 p.375. F = ((SSt-SSc)/k-1)/(SSc/DFc)
elevation.f.test<-((slope[7,4]-slope[6,4])/3)/(slope[6,4]/slope[6,6])

#F-elevation = 22.60, p<0.001

###NEED TUKEY FOR ELEVATIONS BECAUSE null hypothesis that B1=B2=B3=B4 is rejected

#Tukey HSD test for multiple comparisons among elevations (Zar 18.7 p376) 
#q=abs((mean Y1-mean Y2)-b_common(mean X1 - mean X2))/SE
#For critical values from the q-distribution, see Zar p.723
tukey<-matrix(nrow=6, ncol=8)
rownames(tukey)<-c("lm_1 v lm_2", "lm_1 v lm_3", "lm_1 v lm_4", "lm_2 v lm_3", "lm_2 v lm_4", "lm_3 v lm_4")
colnames(tukey)<-c("mean X1", "mean X2", "mean Y1", "mean Y2", "X difference","Y difference", "SE", "q") 

tukey[1,1]<-mean(data$t)
tukey[2,1]<-mean(data$t)
tukey[3,1]<-mean(data$t)
tukey[4,1]<-mean(data$t)
tukey[5,1]<-mean(data$t)
tukey[6,1]<-mean(data$t)

tukey[1,2]<-mean(data$t)
tukey[2,2]<-mean(data$t)
tukey[3,2]<-mean(data$t)
tukey[4,2]<-mean(data$t)
tukey[5,2]<-mean(data$t)
tukey[6,2]<-mean(data$t)

#lm_1 <-f.high, lm_2<-f.low, lm_3<-f.actual, lm_4<-f.mean
#mean Y1
tukey[1,3]<-mean(data$f.high)
tukey[2,3]<-mean(data$f.high)
tukey[3,3]<-mean(data$f.high)
tukey[4,3]<-mean(data$f.low)
tukey[5,3]<-mean(data$f.low)
tukey[6,3]<-mean(data$f.actual)

#mean Y2
tukey[1,4]<-mean(data$f.low)
tukey[2,4]<-mean(data$f.actual)
tukey[3,4]<-mean(data$f.mean)
tukey[4,4]<-mean(data$f.actual)
tukey[5,4]<-mean(data$f.mean)
tukey[6,4]<-mean(data$f.mean)

#X difference
tukey[1,5]<-tukey[1,1]-tukey[1,2]
tukey[2,5]<-tukey[2,1]-tukey[2,2]
tukey[3,5]<-tukey[3,1]-tukey[3,2]
tukey[4,5]<-tukey[4,1]-tukey[4,2]
tukey[5,5]<-tukey[5,1]-tukey[5,2]
tukey[6,5]<-tukey[6,1]-tukey[6,2]

#Y difference
tukey[1,6]<-tukey[1,3]-tukey[1,4]
tukey[2,6]<-tukey[2,3]-tukey[2,4]
tukey[3,6]<-tukey[3,3]-tukey[3,4]
tukey[4,6]<-tukey[4,3]-tukey[4,4]
tukey[5,6]<-tukey[5,3]-tukey[5,4]
tukey[6,6]<-tukey[6,3]-tukey[6,4]

#SE
tukey[1,7]<-sqrt((slope[6,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[1,5]^2)/(slope[2,1]+slope[1,1]))))#lm1 v lm2
tukey[2,7]<-sqrt((slope[6,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[2,5]^2)/(slope[3,1]+slope[1,1]))))
tukey[3,7]<-sqrt((slope[6,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[3,5]^2)/(slope[4,1]+slope[1,1]))))
tukey[4,7]<-sqrt((slope[6,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[4,5]^2)/(slope[3,1]+slope[2,1]))))
tukey[5,7]<-sqrt((slope[6,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[4,5]^2)/(slope[4,1]+slope[2,1]))))
tukey[6,7]<-sqrt((slope[6,8]/2)*((1/length(data$t))+(1/length(data$t))+((tukey[4,5]^2)/(slope[4,1]+slope[3,1]))))

#q -> Tukey HSD test statistic q=abs((Ya-Yb)-bc(Xa-Xb))/SE
tukey[1,8]<-abs((tukey[1,6]-(slope[6,7]*tukey[1,5]))/tukey[1,7])
tukey[2,8]<-abs((tukey[2,6]-(slope[6,7]*tukey[2,5]))/tukey[2,7])
tukey[3,8]<-abs((tukey[3,6]-(slope[6,7]*tukey[3,5]))/tukey[3,7])
tukey[4,8]<-abs((tukey[4,6]-(slope[6,7]*tukey[4,5]))/tukey[4,7])
tukey[5,8]<-abs((tukey[5,6]-(slope[6,7]*tukey[5,5]))/tukey[5,7])
tukey[6,8]<-abs((tukey[6,6]-(slope[6,7]*tukey[6,5]))/tukey[6,7])



